@@ -17,11 +17,10 @@ from grid.utilities import introspect_module
 
 
 @click.group()
-@click.option(
-    '--debug',
-    type=bool,
-    help='Used for logging additional information for debugging purposes.',
-    is_flag=True)
+@click.option('--debug',
+              type=bool,
+              help='Used for logging additional information for debugging purposes.',
+              is_flag=True)
 def main(debug: bool = True) -> None:
     """Grid CLI"""
     if debug:
