@@ -5,7 +5,7 @@ import click
 from dateutil.parser import parse as date_string_parse
 from rich.console import Console
 
-from grid import Grid
+from grid.client import Grid
 from grid.observables import BaseObservable
 
 
@@ -18,8 +18,7 @@ def credentials(ctx, set_default: Optional[str] = None) -> None:
 
     if ctx.invoked_subcommand is None:
         if set_default:
-            client.credentials_update(credential_id=set_default,
-                                      is_default=True)
+            client.credentials_update(credential_id=set_default, is_default=True)
 
         result = client.get_credentials()
         print_creds_table(result['getUserCredentials'])
@@ -30,14 +29,9 @@ def credentials(ctx, set_default: Optional[str] = None) -> None:
               type=click.Choice(['aws'], case_sensitive=False),
               help='Credential provider.',
               required=True)
-@click.option('--file',
-              type=click.File('r'),
-              help='JSON file to where credentials are',
-              required=True)
+@click.option('--file', type=click.File('r'), help='JSON file to where credentials are', required=True)
 @click.option('--alias', type=str, help='Given name for a credential set')
-@click.option('--description',
-              type=str,
-              help='Description for a credential set')
+@click.option('--description', type=str, help='Description for a credential set')
 def add(provider: Optional[str] = None,
         file: Optional[click.File] = None,
         alias: Optional[str] = None,
@@ -47,10 +41,7 @@ def add(provider: Optional[str] = None,
 
     #  Creates new credentials.
     creds = json.load(file)
-    client.credentials_add(provider=provider,
-                           credentials=creds,
-                           alias=alias,
-                           description=description)
+    client.credentials_add(provider=provider, credentials=creds, alias=alias, description=description)
 
     #  Print credentials in terminal.
     result = client.get_credentials()
@@ -68,16 +59,13 @@ def print_creds_table(creds: List[Dict[str, Any]]) -> Console:
 
             """
         raise click.ClickException(message)
-    table = BaseObservable.create_table(columns=[
-        'Credential', 'Provider', 'Alias', 'Created At', 'Last Used At',
-        'Default'
-    ])
+    table = BaseObservable.create_table(
+        columns=['Credential', 'Provider', 'Alias', 'Created At', 'Last Used At', 'Default'])
 
     for row in creds:
         created_at = date_string_parse(row['createdAt'])
         _created_at = f'{created_at:%Y-%m-%d %H:%M}'
-        table.add_row(row['credentialId'], row['provider'], row['alias'],
-                      _created_at, row['lastUsedAt'],
+        table.add_row(row['credentialId'], row['provider'], row['alias'], _created_at, row['lastUsedAt'],
                       str(row['defaultCredential']))
 
     console = Console()
