@@ -1,6 +1,6 @@
 import click
 
-from grid import Grid
+from grid.client import Grid
 
 
 @click.group()
@@ -29,7 +29,7 @@ def experiment(experiment_ids: [str]):
     doublecheck(experiment_ids)
     client = Grid()
     for experiment in experiment_ids:
-        client.delete(experiment_id=experiment)
+        client.delete(experiment_name=experiment)
 
 
 @delete.command()
@@ -38,4 +38,4 @@ def run(run_ids: [str]):
     doublecheck(run_ids)
     client = Grid()
     for run in run_ids:
-        client.delete(run_id=run)
+        client.delete(run_name=run)
