@@ -1,6 +1,6 @@
 import click
 
-from grid import Grid
+from grid.client import Grid
 
 
 @click.command()
