@@ -7,12 +7,12 @@ import click
 from coolname import generate_slug
 import yaml
 
-from grid import Grid
 from grid.cli.grid_credentials import print_creds_table
-from grid.cli.grid_train import _check_run_name_is_valid
+from grid.cli.grid_train import _check_run_name_is_valid, _resolve_instance_type_nickname, _get_instance_types
 from grid.cli.utilities import read_config
 from grid.cli.utilities import validate_config
 from grid.cli.utilities import validate_disk_size_callback
+from grid.client import Grid
 import grid.globals as env
 from grid.tracking import Segment
 from grid.tracking import TrackingEvents
@@ -20,10 +20,8 @@ from grid.types import ObservableType
 from grid.utilities import check_description_isnt_too_long
 
 
-def _print_submission_message(instance_type: str, provider: str,
-                              credential_id: str, name: str,
-                              datastore_name: str, datastore_version: str,
-                              datastore_mount_dir: str):
+def _print_submission_message(instance_type: str, provider: str, credential_id: str, name: str, datastore_name: str,
+                              datastore_version: str, datastore_mount_dir: str):
     """Prints train submission message to the client."""
     message = f"""
         Interactive node created!
@@ -46,14 +44,13 @@ def _print_submission_message(instance_type: str, provider: str,
     click.echo(message)
 
 
-def _generate_default_interactive_config(
-        client: Grid,
-        credential_id: str,
-        instance_type: str,
-        datastore_name: Optional[str] = None,
-        datastore_version: Optional[str] = None,
-        datastore_mount_dir: Optional[str] = None,
-        disk_size: Optional[int] = None):
+def _generate_default_interactive_config(client: Grid,
+                                         credential_id: str,
+                                         instance_type: str,
+                                         datastore_name: Optional[str] = None,
+                                         datastore_version: Optional[str] = None,
+                                         datastore_mount_dir: Optional[str] = None,
+                                         disk_size: Optional[int] = None):
     """
     Generates a new default config file for user if user hasn't
     submitted one.
@@ -71,9 +68,8 @@ def _generate_default_interactive_config(
                     break
 
         if not _default_credential:
-            raise click.ClickException(
-                f'Credential ID {credential_id} does not exist. ' +
-                'Use grid credentials to see available credential IDs.')
+            raise click.ClickException(f'Credential ID {credential_id} does not exist. ' +
+                                       'Use grid credentials to see available credential IDs.')
     else:
         _url = client.url.replace('/graphql', '')
         no_credentials_message = f"""
@@ -90,9 +86,8 @@ def _generate_default_interactive_config(
         elif len(creds) > 1:
             for credential in creds:
                 if credential['defaultCredential']:
-                    click.echo(
-                        f"Using default cloud credentials {credential['credentialId']} "
-                        f"to run on {credential['provider'].upper()}.")
+                    click.echo(f"Using default cloud credentials {credential['credentialId']} "
+                               f"to run on {credential['provider'].upper()}.")
                     _default_credential = credential
                     break
 
@@ -132,8 +127,7 @@ def _generate_default_interactive_config(
                 'datastore_name': datastore_name,
                 'datastore_version': datastore_version,
                 'datastore_mount_dir': datastore_mount_dir,
-                'scale_down_seconds':
-                30 * 60,  # How many seconds before scaling down?
+                'scale_down_seconds': 30 * 60,  # How many seconds before scaling down?
             }
         }
     }
@@ -180,18 +174,15 @@ def interactive(ctx) -> None:
               required=False,
               help='Interactive node description; useful for note-keeping',
               callback=check_description_isnt_too_long)
-@click.option('--grid_credential',
-              '--g_credential',
-              'credential',
-              type=str,
-              required=False,
-              help='Cloud to run on')
+@click.option('--grid_credential', '--g_credential', 'credential', type=str, required=False, help='Cloud to run on')
 @click.option('--grid_instance_type',
               '--g_instance_type',
               'instance_type',
               type=str,
-              default='g3.8xlarge',
-              help='Instance type to start training session in')
+              default='2_m60_8gb',
+              callback=_resolve_instance_type_nickname,
+              help='Instance type to start training session in',
+              autocompletion=_get_instance_types)
 @click.option('--grid_disk_size',
               '--g_disk_size',
               'disk_size',
@@ -212,48 +203,39 @@ def interactive(ctx) -> None:
               type=str,
               required=False,
               help='Datastore version to be mounted in interactive node')
-@click.option(
-    '--grid_datastore_mount_dir',
-    '--g_datastore_mount_dir',
-    'datastore_mount_dir',
-    type=str,
-    required=False,
-    default='/home/jovyan/datastore',
-    help=
-    'Absolute path to mount Datastore in interactive node. (default to ~/datastore)'
-)
-def create(config: Optional[Dict], name: Optional[str],
-           description: Optional[str], credential: Optional[str],
-           instance_type: str, datastore_name: Optional[str],
-           datastore_version: Optional[str],
-           datastore_mount_dir: Optional[str],
-           disk_size: Optional[int]) -> None:
+@click.option('--grid_datastore_mount_dir',
+              '--g_datastore_mount_dir',
+              'datastore_mount_dir',
+              type=str,
+              required=False,
+              default='/home/jovyan/datastore',
+              help='Absolute path to mount Datastore in interactive node. (default to ~/datastore)')
+def create(config: Optional[Dict], name: Optional[str], description: Optional[str], credential: Optional[str],
+           instance_type: str, datastore_name: Optional[str], datastore_version: Optional[str],
+           datastore_mount_dir: Optional[str], disk_size: Optional[int]) -> None:
     """Creates an interactive node."""
     client = Grid()
 
     tracker = Segment()
-    tracker.send_event(event=TrackingEvents.INTERACTIVE_NODE_CREATED,
-                       properties={'user_input': " ".join(sys.argv)})
+    tracker.send_event(event=TrackingEvents.INTERACTIVE_NODE_CREATED, properties={'user_input': " ".join(sys.argv)})
 
     # make a fun random name when user does not pass in a name
     if name is None:
         name = f'{generate_slug(2)}-{random.randint(0, 1000)}'
-        click.echo(
-            f'No --grid_name passed, naming your interactive node: {name}')
+        click.echo(f'No --grid_name passed, naming your interactive node: {name}')
 
     #  If the user has not passed a grid config file,
     #  then generate one with a set of default options.
     #  We'll add a default instance and the user's
     #  default credentials.
     if not config:
-        _grid_config = _generate_default_interactive_config(
-            client=client,
-            datastore_name=datastore_name,
-            datastore_version=datastore_version,
-            datastore_mount_dir=datastore_mount_dir,
-            credential_id=credential,
-            instance_type=instance_type,
-            disk_size=disk_size)
+        _grid_config = _generate_default_interactive_config(client=client,
+                                                            datastore_name=datastore_name,
+                                                            datastore_version=datastore_version,
+                                                            datastore_mount_dir=datastore_mount_dir,
+                                                            credential_id=credential,
+                                                            instance_type=instance_type,
+                                                            disk_size=disk_size)
 
     else:
         _grid_config = config
@@ -261,26 +243,22 @@ def create(config: Optional[Dict], name: Optional[str],
     validate_config(cfg=_grid_config)
 
     client.validate_datastore_version(grid_config=_grid_config)
-    datastore_version = _grid_config["compute"]["train"].get(
-        "datastore_version")
+    datastore_version = _grid_config["compute"]["train"].get("datastore_version")
 
     _grid_config_yaml = yaml.dump(_grid_config)
 
     #  Send to client.
-    client.create_interactive_node(config=_grid_config_yaml,
-                                   name=name,
-                                   description=description)
+    client.create_interactive_node(config=_grid_config_yaml, name=name, description=description)
 
     #  Shows a friendly submission message to the
     #  user.
-    _print_submission_message(
-        instance_type=_grid_config['compute']['train']['instance'],
-        provider=_grid_config['compute']['provider']['vendor'],
-        credential_id=_grid_config['compute']['provider']['credentials'],
-        datastore_name=datastore_name,
-        datastore_version=datastore_version,
-        datastore_mount_dir=datastore_mount_dir,
-        name=name)
+    _print_submission_message(instance_type=_grid_config['compute']['train']['instance'],
+                              provider=_grid_config['compute']['provider']['vendor'],
+                              credential_id=_grid_config['compute']['provider']['credentials'],
+                              datastore_name=datastore_name,
+                              datastore_version=datastore_version,
+                              datastore_mount_dir=datastore_mount_dir,
+                              name=name)
 
 
 @interactive.command()
@@ -307,12 +285,14 @@ def delete(interactive_node: str) -> None:
     client.delete_interactive_node(interactive_node_name=interactive_node)
 
 
-@interactive.command()
-def sync_ssh_config():
+def _update_ssh_config_and_check_ixsession_status(ctx, param, value: str) -> int:
     """
-    Sync interactive node's ssh config to the local ssh config.
+    This updates the SSH config for interactive nodes and
+    also checks if those nodes can be interacted with SSH
+    before attempting an operation. This prevents SSHing into
+    nodes that are not un a running state, e.g. paused or pending.
 
-    It manages a section within user's ssh config file
+    This manages a section within user's ssh config file
     for all interactive nodes shh config details
 
     Afterwards you can use systems ssh & related utilities
@@ -321,14 +301,39 @@ def sync_ssh_config():
 
     The default file is ~/.ssh/config and  can be changed via
     envvar GRID_SSH_CONFIG
+
+    Returns
+    --------
+    value: str
+        Unmodified value if valid
     """
     client = Grid()
     nodes = client.sync_ssh_config()
+
     click.echo(f"Sync config for {len(nodes)} interactive nodes")
 
+    target_ixsession = None
+    for node in nodes:
+        if node["name"] == value:
+            target_ixsession = node
+
+    # Check if interactive session exists at all
+    if not target_ixsession:
+        session_names = [n["name"] for n in nodes]
+        raise click.BadArgumentUsage(f"Interactive session {value} does not exist. "
+                                     f"Available Interactive Sessions are: {', '.join(session_names)}")
+
+    # Check if the node is in 'running' status
+    if target_ixsession["status"] != "running":
+        running_ixsessions = [n["name"] for n in nodes if n["status"] == "running"]
+        raise click.BadArgumentUsage(f"Interactive session {value} is not ready. "
+                                     f"Sessions that are ready to SSH are: {', '.join(running_ixsessions)}")
+
+    return value
+
 
 @interactive.command()
-@click.argument('node_name', type=str)
+@click.argument('node_name', type=str, callback=_update_ssh_config_and_check_ixsession_status)
 def ssh(node_name):
     """
     SSH to interactive nodes.
@@ -345,12 +350,13 @@ def ssh(node_name):
     \f
     """
     client = Grid()
+
     client.sync_ssh_config()
     subprocess.check_call(['ssh', node_name])
 
 
 @interactive.command()
-@click.argument('interactive_node', type=str, nargs=1)
+@click.argument('interactive_node', type=str, nargs=1, callback=_update_ssh_config_and_check_ixsession_status)
 @click.argument('mount_dir', type=str, nargs=1)
 def mount(interactive_node, mount_dir):
     """
@@ -379,6 +385,7 @@ def mount(interactive_node, mount_dir):
     """
     if ':' not in interactive_node:
         interactive_node += ":/home/jovyan"
+
     client = Grid()
     client.sync_ssh_config()
     subprocess.check_call(['sshfs', interactive_node, mount_dir])
