@@ -2,7 +2,7 @@ from typing import Optional
 
 import click
 
-from grid import Grid
+from grid.client import Grid
 import grid.globals as env
 
 
@@ -19,7 +19,7 @@ def login(username: Optional[str] = None, key: Optional[str] = None) -> None:
     if not username:
         username = click.prompt('Please provide your Grid or GitHub username')
     if not key:
-        settings_url = env.GRID_URL.replace("graphql", "#") + "/settings"
+        settings_url = env.GRID_URL.replace("graphql", "") + "#/settings?tabId=apikey"
         click.launch(settings_url)
         key = click.prompt('Please provide your Grid API key')
 
