@@ -5,7 +5,7 @@ import click
 from coolname import generate_slug
 import yaml
 
-from grid import Grid
+from grid.client import Grid
 import grid.globals as env
 from grid.utilities import check_is_python_script
 
@@ -17,9 +17,7 @@ def slurm(ctx) -> None:
     return
 
 
-def _print_submission_message(instance_type: str, provider: str,
-                              credential_id: str, entrypoint: str,
-                              grid_name: str):
+def _print_submission_message(instance_type: str, provider: str, credential_id: str, entrypoint: str, grid_name: str):
     """Prints train submission message to the client."""
     message = f"""
         Run submitted!
@@ -52,7 +50,6 @@ def get_token(ctx, alias: str) -> None:
 @click.pass_context
 def cancel(ctx, run_name: str) -> None:
     """Cancels a slurm run."""
-    pass
 
 
 @slurm.command()
@@ -60,19 +57,14 @@ def cancel(ctx, run_name: str) -> None:
 @click.pass_context
 def logs(ctx, run_name: str) -> None:
     """Prints the logs from a slurm job."""
-    pass
 
 
 @slurm.command()
-@click.option(
-    '--cluster_alias',
-    required=True,
-    type=str,
-    help='The alias assigned to the daemon running in your SLURM cluster.')
-@click.option('--run_name',
-              required=False,
+@click.option('--cluster_alias',
+              required=True,
               type=str,
-              help='Name of a run to see a status for.')
+              help='The alias assigned to the daemon running in your SLURM cluster.')
+@click.option('--run_name', required=False, type=str, help='Name of a run to see a status for.')
 @click.pass_context
 def status(ctx, cluster_alias: str, run_name: str = None):
     """Get's status for jobs in slurm."""
@@ -82,17 +74,11 @@ def status(ctx, cluster_alias: str, run_name: str = None):
 
 
 @slurm.command(context_settings=dict(ignore_unknown_options=True))
-@click.option('--grid_name',
-              '--g_name',
-              'name',
+@click.option('--grid_name', '--g_name', 'name', type=str, required=False, help='Name for this run')
+@click.option('--cluster_alias',
               type=str,
-              required=False,
-              help='Name for this run')
-@click.option(
-    '--cluster_alias',
-    type=str,
-    required=True,
-    help='The alias assigned to the daemon running in your SLURM cluster.')
+              required=True,
+              help='The alias assigned to the daemon running in your SLURM cluster.')
 @click.option(
     '--ntasks',
     type=int,
@@ -100,44 +86,24 @@ def status(ctx, cluster_alias: str, run_name: str = None):
     help=
     'This option advises the Slurm controller that job steps run within the allocation will launch a maximum of number tasks and to provide for sufficient resources.'
 )
-@click.option('--ntasks_per_node',
-              type=int,
-              required=False,
-              help='Request that ntasks be invoked on each node.')
-@click.option('--job_time',
-              type=str,
-              required=False,
-              help='Set a limit on the total run time of the job allocation.')
-@click.option('--mem_per_cpu',
-              type=str,
-              required=False,
-              help='Minimum memory required per allocated CPU.')
-@click.option('--gpus',
-              type=int,
-              required=False,
-              help='Specify the total number of GPUs required for the job.')
+@click.option('--ntasks_per_node', type=int, required=False, help='Request that ntasks be invoked on each node.')
+@click.option('--job_time', type=str, required=False, help='Set a limit on the total run time of the job allocation.')
+@click.option('--mem_per_cpu', type=str, required=False, help='Minimum memory required per allocated CPU.')
+@click.option('--gpus', type=int, required=False, help='Specify the total number of GPUs required for the job.')
 @click.option(
     '--cpus',
     type=int,
     required=False,
-    help=
-    'Advise the Slurm controller that ensuing job steps will require ncpus number of processors per task.'
-)
-@click.option(
-    '--nodes',
-    type=int,
-    required=False,
-    help='Request that a minimum of minnodes nodes be allocated to this job.')
-@click.argument('script',
-                required=True,
-                type=click.Path(exists=True),
-                callback=check_is_python_script)
+    help='Advise the Slurm controller that ensuing job steps will require ncpus number of processors per task.')
+@click.option('--nodes',
+              type=int,
+              required=False,
+              help='Request that a minimum of minnodes nodes be allocated to this job.')
+@click.argument('script', required=True, type=click.Path(exists=True), callback=check_is_python_script)
 @click.argument('script_args', nargs=-1, type=click.UNPROCESSED)
 @click.pass_context
-def train(ctx, script: str, entrypoint: str, name: Optional[str],
-          cluster_alias: str, ntasks: int, ntasks_per_node: int, job_time: str,
-          mem_per_cpu: int, gpus: int, cpus: int, nodes: int,
-          script_args: Optional[Any]) -> None:
+def train(ctx, script: str, entrypoint: str, name: Optional[str], cluster_alias: str, ntasks: int, ntasks_per_node: int,
+          job_time: str, mem_per_cpu: int, gpus: int, cpus: int, nodes: int, script_args: Optional[Any]) -> None:
     """Trains on a SLURM cluster"""
     #  Captures all other user arguments that are not
     #  parsed automatically.
@@ -183,19 +149,15 @@ def train(ctx, script: str, entrypoint: str, name: Optional[str],
             click.confirm(cpu_warning, abort=True)
 
     #  Send to client.
-    result = client.train_on_slurm(config_str=_config_yaml,
-                                   run_name=name,
-                                   script_args=script_arguments)
+    result = client.train_on_slurm(config_str=_config_yaml, run_name=name, script_args=script_arguments)
     if result['success']:
         #  Shows a friendly submission message to the
         #  user.
-        _print_submission_message(
-            instance_type=f"SLURM Cluster with alias {cluster_alias}",
-            provider="Slurm",
-            credential_id=cluster_alias,
-            entrypoint=entrypoint,
-            grid_name=name)
+        _print_submission_message(instance_type=f"SLURM Cluster with alias {cluster_alias}",
+                                  provider="Slurm",
+                                  credential_id=cluster_alias,
+                                  entrypoint=entrypoint,
+                                  grid_name=name)
     else:
         message = result['message']
-        raise click.ClickException(
-            f"Unable to submit train task with error {message}")
+        raise click.ClickException(f"Unable to submit train task with error {message}")
