@@ -4,13 +4,12 @@ import click
 from rich.console import Console
 from rich.table import Table
 
-from grid import Grid
+from grid.client import Grid
 
 
 @click.group()
 def ssh_keys() -> None:
     """Manage SSH keys in Grid"""
-    pass
 
 
 @ssh_keys.command(help="Register a new SSH public key and give it name.")
@@ -21,21 +20,14 @@ def add(name: str, key: str):
     result = Grid().add_ssh_public_key(key=key, name=name)
 
     if result['addSSHPublicKey'].get('success'):
-        click.echo(
-            f"Added key {name} with id: {result['addSSHPublicKey']['id']}")
+        click.echo(f"Added key {name} with id: {result['addSSHPublicKey']['id']}")
 
     else:
         raise click.ClickException(f"Failed to add key: {key}")
 
 
-@ssh_keys.command(help="list currently registered SSH public keys",
-                  name="list")
-@click.option('--limit',
-              'limit',
-              type=int,
-              required=False,
-              default=100,
-              help='maximum number of public keys to fetch')
+@ssh_keys.command(help="list currently registered SSH public keys", name="list")
+@click.option('--limit', 'limit', type=int, required=False, default=100, help='maximum number of public keys to fetch')
 def ls(limit: int):
     table = Table(show_header=True, header_style="bold green")
     table.add_column('id', style='dim')
@@ -48,16 +40,10 @@ def ls(limit: int):
     Console().print(table)
 
 
-@ssh_keys.command(
-    name="authorized_keys",
-    hidden=True,
-    help="list all registered SSH public keys in authorized_keys format")
-@click.option('--limit',
-              'limit',
-              type=int,
-              required=False,
-              default=100,
-              help='maximum number of public keys to fetch')
+@ssh_keys.command(name="authorized_keys",
+                  hidden=True,
+                  help="list all registered SSH public keys in authorized_keys format")
+@click.option('--limit', 'limit', type=int, required=False, default=100, help='maximum number of public keys to fetch')
 def authorized_keys(limit: int):
     for row in Grid().list_public_ssh_keys(limit):
         click.echo(f"#ID {row['id'].strip()}")
