@@ -1,3 +1,4 @@
+from collections import OrderedDict
 import random
 import shlex
 import sys
@@ -6,21 +7,19 @@ from typing import Any, Dict, Optional
 import click
 from coolname import generate_slug
 
-from grid import Grid
 from grid.cli.grid_credentials import print_creds_table
 from grid.cli.utilities import read_config
 from grid.cli.utilities import validate_config
 from grid.cli.utilities import validate_disk_size_callback
+from grid.client import Grid
 import grid.globals as env
 from grid.tracking import Segment
 from grid.tracking import TrackingEvents
 from grid.types import WorkflowType
 from grid.utilities import check_description_isnt_too_long
-from grid.utilities import is_experiment
 
 
-def get_credentials(client: Grid,
-                    grid_credential: Optional[str] = None) -> Dict[str, str]:
+def get_credentials(client: Grid, grid_credential: Optional[str] = None) -> Dict[str, str]:
     """
     Get credentials based on either grid credential or default credential
 
@@ -37,9 +36,8 @@ def get_credentials(client: Grid,
                 if credential['credentialId'] == grid_credential:
                     return credential
 
-        raise click.ClickException(
-            f'Credential {grid_credential} does not exist. ' +
-            'Use grid credentials to see available credential IDs.')
+        raise click.ClickException(f'Credential {grid_credential} does not exist. ' +
+                                   'Use grid credentials to see available credential IDs.')
 
     _url = client.url.replace('/graphql', '')
     no_credentials_message = f"""
@@ -55,9 +53,8 @@ def get_credentials(client: Grid,
 
     for credential in creds:
         if credential['defaultCredential']:
-            click.echo(
-                f"Using default cloud credentials {credential['credentialId']} "
-                f"to run on {credential['provider'].upper()}.")
+            click.echo(f"Using default cloud credentials {credential['credentialId']} "
+                       f"to run on {credential['provider'].upper()}.")
             return credential
 
     # If no default credentials are available, raise an exception.
@@ -112,11 +109,8 @@ def _check_ignore_warnings_flag(ctx, _param, value):
     return value
 
 
-def _print_submission_message(instance_type: str, provider: str,
-                              credential_id: str, entrypoint: str,
-                              grid_name: str, datastore_name: str,
-                              datastore_version: int,
-                              datastore_mount_dir: str):
+def _print_submission_message(instance_type: str, provider: str, credential_id: str, entrypoint: str, grid_name: str,
+                              datastore_name: str, datastore_version: int, datastore_mount_dir: str):
     """Prints train submission message to the client."""
     message = f"""
         Run submitted!
@@ -157,8 +151,7 @@ def _generate_default_grid_config(client: Grid,
     Generates a new default config file for user if user hasn't
     submitted one.
     """
-    _default_credential = get_credentials(client=client,
-                                          grid_credential=grid_credential)
+    _default_credential = get_credentials(client=client, grid_credential=grid_credential)
 
     #  Relevant defaults for user.
     #  TODO: Pull from user profile when we have
@@ -181,8 +174,7 @@ def _generate_default_grid_config(client: Grid,
                 'nodes': 0,  # How many nodes are created at first.
                 'max_nodes': max_nodes,
                 'gpus': gpus,
-                'scale_down_seconds':
-                30 * 60,  # 30 minutes before scaling down.
+                'scale_down_seconds': 30 * 60,  # 30 minutes before scaling down.
                 'disk_size': disk_size,
                 'memory': memory,
                 'cpus': cpus,
@@ -197,12 +189,7 @@ def _generate_default_grid_config(client: Grid,
         if not _grid_config.get('hyper_params'):
             _grid_config['hyper_params'] = {}
 
-        _grid_config['hyper_params'] = {
-            'settings': {
-                'strategy': grid_strategy
-            },
-            'params': {}
-        }
+        _grid_config['hyper_params'] = {'settings': {'strategy': grid_strategy}, 'params': {}}
 
         #  We also add the key trials if that has been
         #  passed. trials is only valid when doing a `random_search`
@@ -230,31 +217,63 @@ def _check_is_valid_extension(ctx, _param, value):
         return value
 
 
+def _aws_node_to_nickname():
+    aws_node_to_nicknames = OrderedDict({
+        'p3.16xlarge': '8_v100_16gb',
+        'p3dn.24xlarge': '8_v100_32gb',
+        'g4dn.metal': '8_t4_16gb',
+        'p2.8xlarge': '8_k80_12gb',
+        'p3.8xlarge': '4_v100_16gb',
+        'g4dn.12xlarge': '4_t4_16gb',
+        'g3.16xlarge': '4_m60_8gb',
+        'g3.8xlarge': '2_m60_8gb',
+        'p3.2xlarge': '1_v100_16gb',
+        'g4dn.8xlarge': '1_t4_16gb',
+        'g4dn.4xlarge': '1_t4_16gb',
+        'g4dn.2xlarge': '1_t4_16gb',
+        'g4dn.xlarge': '1_t4_16gb',
+        'g4dn.16xlarge': '1_t4_16gb',
+        'p2.xlarge': '1_k80_12gb',
+        'g3s.xlarge': '1_m60_8gb',
+        'g3.4xlarge': '1_m60_8gb',
+        't2.large': '2_cpu_8gb',
+        't2.medium': '2_cpu_4gb'
+    })
+    return aws_node_to_nicknames
+
+
+def _nickname_to_aws_nodes():
+    aws_node_to_nickname = _aws_node_to_nickname()
+    aws_nickname_to_node = {v: k for k, v in aws_node_to_nickname.items()}
+    return aws_nickname_to_node
+
+
+def _resolve_instance_type_nickname(ctx, _param, value):
+    """
+    Enables instance type shortcuts like:
+    2_cpu_4gb for t2.large
+    """
+    nickname = value.lower()
+
+    aws_nickname_to_node = _nickname_to_aws_nodes()
+
+    # validate potential options for the node name
+    possible_values = list(aws_nickname_to_node.keys()) + list(aws_nickname_to_node.values())
+    if nickname not in possible_values:
+        possible_options = '\n'.join(list(aws_nickname_to_node.keys()))
+        click.BadParameter(f'{nickname} is not an available instance_type\n try one of these:\n{possible_options}')
+
+    instance_type = nickname
+
+    # if the value has _ then it's a nickname
+    if '_' in nickname:
+        instance_type = aws_nickname_to_node[nickname]
+    return instance_type
+
+
 def _get_instance_types(ctx, args, incomplete):
     # TODO: these should be retrieved from backend
-    instance_types = [
-        "p3.16xlarge",
-        "p3dn.24xlarge",
-        "p3.16xlarge",
-        "g4dn.metal",
-        "p2.8xlarge",
-        "p3.8xlarge",
-        "g4dn.12xlarge",
-        "g3.16xlarge",
-        "g3.8xlarge",
-        "p3.2xlarge",
-        "g4dn.16xlarge",
-        "g4dn.8xlarge",
-        "g4dn.4xlarge",
-        "g4dn.2xlarge",
-        "g4dn.xlarge",
-        "p2.xlarge",
-        "g3.4xlarge",
-        "g3s.xlarge",
-        "t2.large",
-        "t2.medium",
-    ]
-    return [x for x in instance_types if incomplete in x]
+    return list(_aws_node_to_nickname().keys())
 
 
 @click.command(context_settings=dict(ignore_unknown_options=True))
@@ -279,17 +298,11 @@ def _get_instance_types(ctx, args, incomplete):
               required=False,
               help='Run description; useful for note-keeping',
               callback=check_description_isnt_too_long)
-@click.option('--grid_credential',
-              '--g_credential',
-              'credential',
-              type=str,
-              required=False,
-              help='Cloud to run on')
+@click.option('--grid_credential', '--g_credential', 'credential', type=str, required=False, help='Cloud to run on')
 @click.option('--grid_strategy',
               '--g_strategy',
               'strategy',
-              type=click.Choice(['grid_search', 'random_search'],
-                                case_sensitive=False),
+              type=click.Choice(['grid_search', 'random_search'], case_sensitive=False),
               required=False,
               help='Hyperparameter search strategy')
 @click.option('--grid_trials',
@@ -302,7 +315,8 @@ def _get_instance_types(ctx, args, incomplete):
               '--g_instance_type',
               'instance_type',
               type=str,
-              default='g3.8xlarge',
+              default='2_m60_8gb',
+              callback=_resolve_instance_type_nickname,
               help='Instance type to start training session in',
               autocompletion=_get_instance_types)
 @click.option('--grid_gpus',
@@ -330,15 +344,14 @@ def _get_instance_types(ctx, args, incomplete):
 #    default=1,
 #    help='Number of training processes to run per experiment. Using larger than 1 ' \
 #         'will start a multi-node training')
-@click.option(
-    '--grid_disk_size',
-    '--g_disk_size',
-    'disk_size',
-    type=int,
-    required=False,
-    default=200,
-    callback=validate_disk_size_callback,
-    help='The disk size in GB to allocate to each node in the cluster')
+@click.option('--grid_disk_size',
+              '--g_disk_size',
+              'disk_size',
+              type=int,
+              required=False,
+              default=200,
+              callback=validate_disk_size_callback,
+              help='The disk size in GB to allocate to each node in the cluster')
 @click.option('--grid_max_nodes',
               '--g_max_nodes',
               'max_nodes',
@@ -383,21 +396,14 @@ def _get_instance_types(ctx, args, incomplete):
               required=False,
               help='If we should ignore warning when executing commands',
               callback=_check_ignore_warnings_flag)
-@click.argument('script',
-                type=click.Path(exists=True),
-                callback=_check_is_valid_extension)
+@click.argument('script', type=click.Path(exists=True), callback=_check_is_valid_extension)
 @click.argument('script_args', nargs=-1, type=click.UNPROCESSED)
 @click.pass_context
-def train(ctx, script: str, entrypoint: str, config: Optional[Dict],
-          name: Optional[str], credential: Optional[str],
-          strategy: Optional[str], trials: Optional[int], instance_type: str,
-          gpus: Optional[int], disk_size: Optional[int],
-          max_nodes: Optional[int], description: Optional[str],
-          ignore_warnings: bool, script_args: Optional[Any],
-          memory: Optional[str], cpus: Optional[int],
-          datastore_name: Optional[str], datastore_version: Optional[str],
-          datastore_mount_dir: Optional[str],
-          framework: Optional[str]) -> None:
+def train(ctx, script: str, entrypoint: str, config: Optional[Dict], name: Optional[str], credential: Optional[str],
+          strategy: Optional[str], trials: Optional[int], instance_type: str, gpus: Optional[int],
+          disk_size: Optional[int], max_nodes: Optional[int], description: Optional[str], ignore_warnings: bool,
+          script_args: Optional[Any], memory: Optional[str], cpus: Optional[int], datastore_name: Optional[str],
+          datastore_version: Optional[str], datastore_mount_dir: Optional[str], framework: Optional[str]) -> None:
     """Trains scripts in remote infrastructure"""
 
     # Captures all other user arguments that are not
@@ -420,8 +426,7 @@ def train(ctx, script: str, entrypoint: str, config: Optional[Dict],
     client = Grid()
 
     tracker = Segment()
-    tracker.send_event(event=TrackingEvents.RUN_CREATED,
-                       properties={'user_input': invocation_command})
+    tracker.send_event(event=TrackingEvents.RUN_CREATED, properties={'user_input': invocation_command})
 
     # make a fun random name when user does not pass in a name
     if name is None:
@@ -433,22 +438,21 @@ def train(ctx, script: str, entrypoint: str, config: Optional[Dict],
     #  We'll add a default instance and the user's
     #  default credentials.
     if not config:
-        _grid_config = _generate_default_grid_config(
-            client=client,
-            grid_credential=credential,
-            grid_strategy=strategy,
-            grid_trials=trials,
-            instance_type=instance_type,
-            processes=1,
-            gpus=gpus,
-            max_nodes=max_nodes,
-            disk_size=disk_size,
-            memory=memory,
-            cpus=cpus,
-            datastore_name=datastore_name,
-            datastore_version=datastore_version,
-            datastore_mount_dir=datastore_mount_dir,
-            framework=framework)
+        _grid_config = _generate_default_grid_config(client=client,
+                                                     grid_credential=credential,
+                                                     grid_strategy=strategy,
+                                                     grid_trials=trials,
+                                                     instance_type=instance_type,
+                                                     processes=1,
+                                                     gpus=gpus,
+                                                     max_nodes=max_nodes,
+                                                     disk_size=disk_size,
+                                                     memory=memory,
+                                                     cpus=cpus,
+                                                     datastore_name=datastore_name,
+                                                     datastore_version=datastore_version,
+                                                     datastore_mount_dir=datastore_mount_dir,
+                                                     framework=framework)
 
     else:
         _grid_config = config
@@ -456,8 +460,7 @@ def train(ctx, script: str, entrypoint: str, config: Optional[Dict],
     validate_config(cfg=_grid_config)
 
     client.validate_datastore_version(grid_config=_grid_config)
-    datastore_version = _grid_config["compute"]["train"].get(
-        "datastore_version")
+    datastore_version = _grid_config["compute"]["train"].get("datastore_version")
 
     # Warn user if they have not specified a cpu or gpu number so cpus will be set to 1
     cpus = _grid_config['compute']['train'].get('cpus')
@@ -490,14 +493,11 @@ def train(ctx, script: str, entrypoint: str, config: Optional[Dict],
 
     #  Shows a friendly submission message to the
     #  user.
-    _print_submission_message(
-        instance_type=_grid_config['compute']['train']['instance'],
-        provider=_grid_config['compute']['provider']['vendor'],
-        credential_id=_grid_config['compute']['provider']['credentials'],
-        entrypoint=entrypoint,
-        grid_name=name,
-        datastore_name=_grid_config['compute']['train']['datastore_name'],
-        datastore_version=_grid_config['compute']['train']
-        ['datastore_version'],
-        datastore_mount_dir=_grid_config['compute']['train']
-        ['datastore_mount_dir'])
+    _print_submission_message(instance_type=_grid_config['compute']['train']['instance'],
+                              provider=_grid_config['compute']['provider']['vendor'],
+                              credential_id=_grid_config['compute']['provider']['credentials'],
+                              entrypoint=entrypoint,
+                              grid_name=name,
+                              datastore_name=_grid_config['compute']['train']['datastore_name'],
+                              datastore_version=_grid_config['compute']['train']['datastore_version'],
+                              datastore_mount_dir=_grid_config['compute']['train']['datastore_mount_dir'])
