@@ -47,15 +47,12 @@ class WorkflowChecksMixin:
     @staticmethod
     def _check_github_repository() -> None:
         """Checks if the active directory is a GitHub repository."""
-        github_repository = execute_git_command(
-            ["config", "--get", "remote.origin.url"])
+        github_repository = execute_git_command(["config", "--get", "remote.origin.url"])
         env.logger.debug(github_repository)
 
         if not github_repository or 'github.com' not in github_repository:
-            raise click.ClickException(
-                '`grid train` or `grid interactive` can only be run in a git repository '
-                'hosted on github.com. See docs for details: https://docs.grid.ai'
-            )
+            raise click.ClickException('`grid train` or `grid interactive` can only be run in a git repository '
+                                       'hosted on github.com. See docs for details: https://docs.grid.ai')
 
     @staticmethod
     def _check_if_uncommited_files() -> bool:
@@ -72,10 +69,7 @@ class WorkflowChecksMixin:
         files = execute_git_command(['update-index', '--refresh'])
 
         _files = files.split('\n')
-        _files = [
-            click.style(f"  {f.replace(': needs update', '')}", fg='red')
-            for f in _files
-        ]
+        _files = [click.style(f"  {f.replace(': needs update', '')}", fg='red') for f in _files]
 
         files_str = '\n    '.join(_files)
         docs_str = click.style('https://docs.grid.ai', fg='blue')
