@@ -30,8 +30,7 @@ class CredentialsMixin:
         result = self.client.execute(query)
         return result
 
-    def credentials_add(self, provider: str, credentials: Dict[str, str],
-                        alias: str, description: str) -> None:
+    def credentials_add(self, provider: str, credentials: Dict[str, str], alias: str, description: str) -> None:
         """Adds a new credential set to Grid."""
         mutation = gql("""
             mutation (
@@ -87,12 +86,7 @@ class CredentialsMixin:
             }
             """)
 
-        params = {
-            'credentialId': credential_id,
-            'alias': alias,
-            'description': description,
-            'isDefault': is_default
-        }
+        params = {'credentialId': credential_id, 'alias': alias, 'description': description, 'isDefault': is_default}
 
         result = self.client.execute(mutation, variable_values=params)
         click.echo(result['updateCloudCredential']['message'])
