@@ -65,11 +65,9 @@ class DependencyMixin:
 
         if CONDA_REQUIREMENTS_FILE in files:
             if PIP_REQUIREMENTS_FILE in files:  # skipcq: PYL-R1705
-                click.echo(
-                    f"{warning_str} Found both {CONDA_REQUIREMENTS_FILE} "
-                    f"and {PIP_REQUIREMENTS_FILE}. Delete one of them if"
-                    "you need us to run the dependency check. Ignoring for now"
-                )
+                click.echo(f"{warning_str} Found both {CONDA_REQUIREMENTS_FILE} "
+                           f"and {PIP_REQUIREMENTS_FILE}. Delete one of them if"
+                           "you need us to run the dependency check. Ignoring for now")
                 return False
             else:
                 manager_class = CondaManager
@@ -149,10 +147,7 @@ class DependencyMixin:
         user_choice = "2"  # Ignore and continue to train
         if self._deps_manager.has_change:
             valid_choices = click.Choice(("1", "2", "3"))
-            user_choice = click.prompt(message,
-                                       show_default=False,
-                                       default="1",
-                                       type=valid_choices)
+            user_choice = click.prompt(message, show_default=False, default="1", type=valid_choices)
         if user_choice == "3":  # Ignore and exit
             raise click.Abort()
         # True if user decides to change deps and exit
