@@ -19,7 +19,7 @@ import requests
 import yaspin
 
 from grid.tar import get_split_size
-from grid.tar import tar_directory
+from grid.tar import tar_path
 from grid.uploader import S3Uploader
 from grid.uploader import UploadProgressCallback
 
@@ -31,8 +31,7 @@ def check_source(source: str):
     if source.startswith("http"):
         supported_extensions = [".zip", ".tar.gz", ".tar"]
 
-        valid_extension = any(
-            source.endswith(extension) for extension in supported_extensions)
+        valid_extension = any(source.endswith(extension) for extension in supported_extensions)
 
         if valid_extension is False:
             raise ClickException(f"""
@@ -47,14 +46,10 @@ def check_source(source: str):
         return
 
     if os.path.exists(source) is False:
-        raise ClickException(
-            f"Source local directory path {source} doesn't exist")
+        raise ClickException(f"Source local directory path {source} doesn't exist")
 
 
-def create_datastore(name: str,
-                     credential_id: str,
-                     client: Client,
-                     remote_source_url: Optional[str] = None):
+def create_datastore(name: str, credential_id: str, client: Client, remote_source_url: Optional[str] = None):
     """Create datastore in Grid"""
 
     # Create Grid datastore directly in Grid without uploading,
@@ -82,11 +77,7 @@ def create_datastore(name: str,
     }
     """)
 
-    params = {
-        'name': name,
-        'credentialId': credential_id,
-        'remoteSourceUrl': remote_source_url
-    }
+    params = {'name': name, 'credentialId': credential_id, 'remoteSourceUrl': remote_source_url}
 
     result = client.execute(mutation, variable_values=params)
     success = result['createDatastore']['success']
@@ -100,21 +91,14 @@ def create_datastore(name: str,
     return (datastoreId, datastoreVersion)
 
 
-def create_datastore_session(name: str, source: str, credential_id: str,
-                             compression: bool, client: Client):
+def create_datastore_session(name: str, source: str, credential_id: str, compression: bool, client: Client):
     """Creates datastore session based on source"""
     check_source(source)
 
     if source.startswith("http"):
-        return DatastoreRemoteUpload(name=name,
-                                     source_url=source,
-                                     credential_id=credential_id,
-                                     client=client)
+        return DatastoreRemoteUpload(name=name, source_url=source, credential_id=credential_id, client=client)
 
-    s = DatastoreUploadSession(name=name,
-                               source_dir=source,
-                               credential_id=credential_id,
-                               compression=compression)
+    s = DatastoreUploadSession(name=name, source_dir=source, credential_id=credential_id, compression=compression)
     s.configure(client=client)
     return s
 
@@ -148,8 +132,7 @@ class DatastoreRemoteUpload:
     credential_id: str
         Credential Id to map datastore to
     """
-    def __init__(self, name: str, source_url: str, credential_id: str,
-                 client: Client):
+    def __init__(self, name: str, source_url: str, credential_id: str, client: Client):
         self.name = name
         self.source_url = source_url
         self.credential_id = credential_id
@@ -157,8 +140,7 @@ class DatastoreRemoteUpload:
         self.logger = logging.getLogger("grid.datastore")
 
     def upload(self):
-        spinner = yaspin.yaspin(text=f'Creating datastore {self.name}',
-                                color="yellow")
+        spinner = yaspin.yaspin(text=f'Creating datastore {self.name}', color="yellow")
         spinner.start()
 
         try:
@@ -249,8 +231,7 @@ class DatastoreUploadSession(UploadProgressCallback):
         """
         logger = logging.getLogger("DatastoreUploadSession")
         sessions = []
-        session_path = str(Path.home().joinpath(
-            DatastoreUploadSession.grid_datastores_path))
+        session_path = str(Path.home().joinpath(DatastoreUploadSession.grid_datastores_path))
         session_dirs = os.listdir(session_path)
         for session_dir in session_dirs:
             session_dir = os.path.join(session_path, session_dir)
@@ -267,8 +248,7 @@ class DatastoreUploadSession(UploadProgressCallback):
 
                 sessions.append(session)
             except (ValueError, UnsupportedDatastoreImplementationError) as e:
-                logger.warning(
-                    f"Removing incomplete session {session_dir}, reason: {e}")
+                logger.warning(f"Removing incomplete session {session_dir}, reason: {e}")
                 shutil.rmtree(session_dir, ignore_errors=True)
 
         return sessions
@@ -291,9 +271,8 @@ class DatastoreUploadSession(UploadProgressCallback):
                 name = content["name"]
                 version = content["version"]
                 session_name = f"{name}-v{version}"
-                raise UnsupportedDatastoreImplementationError(
-                    f"Incomplete datastore session {session_name} is no " +
-                    "longer supported. Please restart this upload.")
+                raise UnsupportedDatastoreImplementationError(f"Incomplete datastore session {session_name} is no " +
+                                                              "longer supported. Please restart this upload.")
 
             session = DatastoreUploadSession.from_dict(content)
 
@@ -314,9 +293,7 @@ class DatastoreUploadSession(UploadProgressCallback):
     def _get_presigned_urls(self):
         """Gets presigned urls from backend"""
         if self.part_count <= 0:
-            raise InvalidDatastoreError(
-                f"Invalid part count calculated for datastore: {self.part_count}"
-            )
+            raise InvalidDatastoreError(f"Invalid part count calculated for datastore: {self.part_count}")
 
         self._update_progress("Requesting presigned URLs from Grid...")
 
@@ -365,31 +342,26 @@ class DatastoreUploadSession(UploadProgressCallback):
 
     def _create_datastore(self):
         self._update_progress("Creating datastore in Grid...")
-        datastore_id, datastore_version = create_datastore(
-            name=self.name,
-            credential_id=self.credential_id,
-            client=self.client)
+        datastore_id, datastore_version = create_datastore(name=self.name,
+                                                           credential_id=self.credential_id,
+                                                           client=self.client)
         self.id = datastore_id
         self.version = datastore_version
 
     def _compress_source_directory(self):
         if self.compression:
-            self._update_progress(
-                f"Packaging and compressing datastore {self.name}...")
+            self._update_progress(f"Packaging and compressing datastore {self.name}...")
         else:
             self._update_progress(f"Packaging datastore {self.name}...")
 
-        tar_results = tar_directory(source_dir=self.source_dir,
-                                    target_file=self.target_file,
-                                    compression=self.compression)
+        tar_results = tar_path(source_path=self.source_dir, target_file=self.target_file, compression=self.compression)
 
         self.original_size = tar_results.before_size
         self.compressed_size = tar_results.after_size
         split_size = get_split_size(self.compressed_size)
         self.part_count = math.ceil(self.compressed_size / split_size)
 
-    def _create_uploader(self, presigned_urls: Dict[int, str],
-                         already_uploaded_parts: List[int]):
+    def _create_uploader(self, presigned_urls: Dict[int, str], already_uploaded_parts: List[int]):
         size = self.compressed_size
         if size == 0:
             # We added compressed size later, so if a session didn't have it serialized,
@@ -408,9 +380,7 @@ class DatastoreUploadSession(UploadProgressCallback):
                           progress_callback=self)
 
     def _upload_parts(self):
-        self._update_progress(
-            f"Uploading datastore {self.name} (v{self.version}) datastore" +
-            " to S3...")
+        self._update_progress(f"Uploading datastore {self.name} (v{self.version}) datastore" + " to S3...")
 
         # Split urls depending on whether they were already uploaded or not.
         # This can happen if we resume an upload session.
@@ -423,9 +393,8 @@ class DatastoreUploadSession(UploadProgressCallback):
             else:
                 already_uploaded_parts.append(part)
 
-        uploader = self._create_uploader(
-            presigned_urls=unuploaded_presigned_urls,
-            already_uploaded_parts=already_uploaded_parts)
+        uploader = self._create_uploader(presigned_urls=unuploaded_presigned_urls,
+                                         already_uploaded_parts=already_uploaded_parts)
 
         # Stoping and starting the spinner, as the progress bar
         # in uploader will conflict with the spinner
@@ -472,8 +441,7 @@ class DatastoreUploadSession(UploadProgressCallback):
         success = result['completeMultipartDatastoreUpload']['success']
         message = result['completeMultipartDatastoreUpload']['message']
         if not success:
-            raise ValueError(
-                f"Unable to complete multi-part upload: {message}")
+            raise ValueError(f"Unable to complete multi-part upload: {message}")
 
         self._update_progress("Completing datastore upload...")
 
@@ -494,10 +462,7 @@ class DatastoreUploadSession(UploadProgressCallback):
         }
         """)
 
-        params = {
-            'datastoreId': self.id,
-            'sizeMib': math.ceil(self.original_size / (1024**2))
-        }
+        params = {'datastoreId': self.id, 'sizeMib': math.ceil(self.original_size / (1024**2))}
 
         result = self.client.execute(mutation, variable_values=params)
         success = result['completeDatastoreUpload']['success']
@@ -511,8 +476,7 @@ class DatastoreUploadSession(UploadProgressCallback):
         """
         self.session_path = os.path.join(self.grid_datastores_path, session_id)
         self.session_path = str(Path.home().joinpath(self.session_path))
-        Path.home().joinpath(self.session_path).mkdir(parents=True,
-                                                      exist_ok=True)
+        Path.home().joinpath(self.session_path).mkdir(parents=True, exist_ok=True)
         self.session_file = os.path.join(self.session_path, "session.json")
 
     @property
@@ -530,20 +494,14 @@ class DatastoreUploadSession(UploadProgressCallback):
 
         self._create_session_file(self.session_id)
 
-        self.spinner = yaspin.yaspin(
-            text=f'Uploading datastore {self.name} v{self.version}',
-            color="yellow")
+        self.spinner = yaspin.yaspin(text=f'Uploading datastore {self.name} v{self.version}', color="yellow")
         self.spinner.start()
 
-        steps = [(self._create_datastore,
-                  DatastoreUploadSteps.CREATE_DATASTORE),
-                 (self._compress_source_directory,
-                  DatastoreUploadSteps.COMPRESS_SOURCE_DIRECTORY),
-                 (self._get_presigned_urls,
-                  DatastoreUploadSteps.GET_PRESIGNED_URLS),
+        steps = [(self._create_datastore, DatastoreUploadSteps.CREATE_DATASTORE),
+                 (self._compress_source_directory, DatastoreUploadSteps.COMPRESS_SOURCE_DIRECTORY),
+                 (self._get_presigned_urls, DatastoreUploadSteps.GET_PRESIGNED_URLS),
                  (self._upload_parts, DatastoreUploadSteps.UPLOAD_PARTS),
-                 (self._mark_upload_complete,
-                  DatastoreUploadSteps.MARK_UPLOAD_COMPLETE)]
+                 (self._mark_upload_complete, DatastoreUploadSteps.MARK_UPLOAD_COMPLETE)]
 
         current_step = 0
         if self.last_completed_step:
@@ -553,8 +511,7 @@ class DatastoreUploadSession(UploadProgressCallback):
                     break
 
             if current_step == 0:
-                raise ValueError(f"Unsupported upload step: " +
-                                 self.last_completed_step)
+                raise ValueError(f"Unsupported upload step: " + self.last_completed_step)
 
         try:
             while current_step < len(steps):
