@@ -21,17 +21,13 @@ import yaml
 
 # https://www.python.org/dev/peps/pep-0610/
 PACKAGE_URL_METAFILE = "direct_url.json"
-ALLOWED_SCHEMES = {
-    'http', 'https', 'file', 'ftp', 'ssh', 'git', 'sftp', 'git+http',
-    'git+https'
-}
+ALLOWED_SCHEMES = {'http', 'https', 'file', 'ftp', 'ssh', 'git', 'sftp', 'git+http', 'git+https'}
 
 
 class NonComparableError(Exception):
     """
     Two Packages are non-comparable
     """
-    pass
 
 
 def execute_conda_command(args: List[str]):
@@ -212,8 +208,7 @@ def _get_valid_stem(string: str) -> Optional[str]:
             cwd = Path.cwd()
             absolute = path.resolve()
             if cwd not in absolute.parents and cwd != absolute:
-                raise RuntimeError(f"Path outside of current working "
-                                   f"directory are not portable {path}")
+                raise RuntimeError(f"Path outside of current working " f"directory are not portable {path}")
         else:
             raise RuntimeError(f"Error while parsing {string}")
     return path.resolve().stem.split(".")[0]
@@ -241,8 +236,7 @@ def _guess_valid_name(string):
     """
     string = string.strip()
     if string.startswith("-e "):
-        raise RuntimeError("Found editable requirements which might not be"
-                           f"portable {string}")
+        raise RuntimeError("Found editable requirements which might not be" f"portable {string}")
     if "@ " in string:
         # name@ path is not a valid specification in 3.7
         name, _ = string.split("@ ", maxsplit=1)
@@ -286,7 +280,7 @@ class BasePackage(abc.ABC):
 
     @abc.abstractmethod
     def __eq__(self, other: BasePackage) -> bool:
-        raise NotImplementedError
+        return NotImplemented
 
     @abc.abstractmethod
     def __str__(self):
@@ -297,8 +291,7 @@ class CondaPackage(BasePackage):
     """
     Do not call the constructor / init directly. Use classmethod(s) instead
     """
-    def __init__(self, name: Optional[str], version: Optional[str],
-                 build: Optional[str]):
+    def __init__(self, name: Optional[str], version: Optional[str], build: Optional[str]):
         super().__init__(name)
         self.parsed_name = _conda2parsed_pypi(self.name)
         self.version = version
@@ -308,23 +301,19 @@ class CondaPackage(BasePackage):
     def from_string(cls, string: str) -> CondaPackage:
         splits = re.split(r"\W*=\W*", string)
         if len(splits) > 3:
-            raise RuntimeError(f"ParsingError: Conda spec {string} is "
-                               f"not readable")
+            raise RuntimeError(f"ParsingError: Conda spec {string} is " f"not readable")
         expected_elem_count = 3  # name, version and build
         splits = splits + [None] * (expected_elem_count - len(splits))  # noqa
         name, version, build = splits
         return cls(name=name, version=version, build=build)
 
     def __str__(self):
-        not_none = [
-            val for val in (self.name, self.version, self.build) if val
-        ]
+        not_none = [val for val in (self.name, self.version, self.build) if val]
         return "=".join(not_none)
 
     def __eq__(self, other: CondaPackage):
         if other.__class__ is self.__class__:
-            return all((self.version == other.version,
-                        self.parsed_name == other.parsed_name))
+            return all((self.version == other.version, self.parsed_name == other.parsed_name))
         return NotImplemented
 
 
@@ -333,10 +322,7 @@ class PipPackage(BasePackage):
     Offload all parsing, de-parsing, checks etc to `Requirement` object.
     Do not call the constructor / init directly. Use classmethod(s) instead
     """
-    def __init__(self,
-                 name: str,
-                 req_obj: Optional[Requirement] = None,
-                 original_string: Optional[str] = None):
+    def __init__(self, name: str, req_obj: Optional[Requirement] = None, original_string: Optional[str] = None):
         super().__init__(name)
         self._requirement_obj = req_obj
         self._original_string = original_string
@@ -368,8 +354,7 @@ class PipPackage(BasePackage):
     @classmethod
     def from_distribution(cls, dist: pkg_resources.Distribution):
         if _is_dist_editable(dist):
-            raise RuntimeError(f"Found editable installation which might have"
-                               f"local changes {dist.project_name}")
+            raise RuntimeError(f"Found editable installation which might have" f"local changes {dist.project_name}")
         req = dist.as_requirement()
         url = _get_distribution_url(dist)
         # if the URL is available, we'll remove the specifier (version info)
@@ -533,15 +518,11 @@ class DependencyManagerBase(abc.ABC):
         information from different sources such as current environment,
         requirement listing, pypi etc
         """
-        ignore_dirs = [
-            "venv", "test", "tests", "_test", "_tests", "egg", "EGG", "info",
-            "docs", "__pycache__"
-        ]
+        ignore_dirs = ["venv", "test", "tests", "_test", "_tests", "egg", "EGG", "info", "docs", "__pycache__"]
         input_path = Path.cwd()
         for pth in input_path.iterdir():
             # ignore directories beginning with ('.' and '__')
-            if pth.is_dir() and (pth.name.startswith('.')
-                                 or pth.name.startswith('__')):
+            if pth.is_dir() and (pth.name.startswith('.') or pth.name.startswith('__')):
                 ignore_dirs.append(pth.name)
 
         # TODO: remove pipreqs dependency
@@ -600,8 +581,7 @@ class DependencyManagerBase(abc.ABC):
             elif name in self.env_deps:
                 qualified = self.env_deps[name]
             else:
-                raise RuntimeError(f"Package name '{name}' not found in file "
-                                   f"or env")
+                raise RuntimeError(f"Package name '{name}' not found in file " f"or env")
             collated.append(qualified)
         return collated
 
@@ -620,12 +600,10 @@ class DependencyManagerBase(abc.ABC):
             elif "on_image_build" not in config["compute"]["actions"]:
                 config["compute"]["actions"]["on_image_build"] = []
 
-            if not isinstance(config["compute"]["actions"]["on_image_build"],
-                              list):
+            if not isinstance(config["compute"]["actions"]["on_image_build"], list):
                 raise RuntimeError("Parsing error while reading config.yml")
 
-            config["compute"]["actions"]["on_image_build"].append(
-                sys_deps_action)
+            config["compute"]["actions"]["on_image_build"].append(sys_deps_action)
             yaml.safe_dump(config, config_file.open(mode="w+"))
 
 
@@ -635,8 +613,7 @@ class CondaManager(DependencyManagerBase):
     _channels: List[str] = []
 
     @staticmethod
-    def _build_dependency_dict(
-            specs: List) -> Dict[str, Union[CondaPackage, PipPackage]]:
+    def _build_dependency_dict(specs: List) -> Dict[str, Union[CondaPackage, PipPackage]]:
         """
         Build dependency objects from the spec
 
@@ -674,16 +651,14 @@ class CondaManager(DependencyManagerBase):
             # Only pip listing inside a yaml file must be a mapping
             if isinstance(d, dict):
                 if "pip" not in d or len(d) > 1:
-                    raise RuntimeError("Could not parse the conda yaml file. "
-                                       "Raise the issue with Grid support")
+                    raise RuntimeError("Could not parse the conda yaml file. " "Raise the issue with Grid support")
                 pip_dependencies = d["pip"]
             # conda deps listing in a yaml file will be a string
             else:
                 try:
                     dep = CondaPackage.from_string(d)
                 except RuntimeError:
-                    raise RuntimeError("Could not parse the conda yaml file. "
-                                       "Raise the issue with Grid support")
+                    raise RuntimeError("Could not parse the conda yaml file. " "Raise the issue with Grid support")
                 dependencies[dep.parsed_name] = dep
         for elem in pip_dependencies:
             dep = PipPackage.from_string(elem)
