@@ -4,9 +4,6 @@ from typing import List
 import click
 from gql import gql
 from rich.console import Console
-from rich.progress import BarColumn
-from rich.progress import Progress
-from rich.progress import TextColumn
 from rich.table import Table
 from yaspin import yaspin
 
@@ -18,19 +15,15 @@ TASK_CLASS_MAPPING = {
     'grid.core.cluster.Cluster': 'Creating cluster',
     'grid.core.trainer.experiment.Experiment': 'Scheduling experiment',
     'grid.core.trainer.run.RunNodePool': 'Creating node pool',
-    'grid.core.trainer.interactive.InteractiveNodeTask':
-    'Creating interactive node',
-    'grid.core.trainer.experiment.ExperimentsWarpSpeed':
-    'Scheduling experiment'
+    'grid.core.trainer.interactive.InteractiveNodeTask': 'Creating interactive node',
+    'grid.core.trainer.experiment.ExperimentsWarpSpeed': 'Scheduling experiment'
 }
 
 # Backend classes that we don't show to users. These
 # are automatically triggered if a given user does not
 # have global properties set.
-TASK_CLASS_IGNORE = (
-    'grid.core.clusters.deploy_tensorboard.ReconcileTensorboard',
-    'grid.core.clusters.global_user_cluster.ReconcileCluster',
-    'grid.core.user.ReconcileUser')
+TASK_CLASS_IGNORE = ('grid.core.clusters.deploy_tensorboard.ReconcileTensorboard',
+                     'grid.core.clusters.global_user_cluster.ReconcileCluster', 'grid.core.user.ReconcileUser')
 
 
 def style_status(format_string: str, status: str):
@@ -65,8 +58,7 @@ class BaseObservable:
     def __init__(self, client, spinner_load_type=""):
         self.client = client
         self.console = Console()
-        self.spinner = yaspin(text=f"Loading {spinner_load_type}...",
-                              color="yellow")
+        self.spinner = yaspin(text=f"Loading {spinner_load_type}...", color="yellow")
 
     @staticmethod
     def create_table(columns: List[str]) -> Table:
@@ -119,8 +111,7 @@ class BaseObservable:
                 click.echo(message)
 
             if 'not found' in message or 'No runs available' in message:
-                raise click.ClickException(
-                    f'Run {run_name} not found. Did you cancel it already?')
+                raise click.ClickException(f'Run {run_name} not found. Did you cancel it already?')
 
         if result:
             dependencies = result['getRunTaskStatus']['dependencies']
@@ -130,6 +121,10 @@ class BaseObservable:
         #  Get dependency data.
         dependencies = self._get_task_run_dependencies(run_name=run_name)
 
+        # short circuit if run has no dependencies
+        if not dependencies:
+            return
+
         #  Dict to collect all errors for given tasks.
         dependency_data = {
             k: {
@@ -142,11 +137,9 @@ class BaseObservable:
         for task in dependencies:
             if task['taskType'] in TASK_CLASS_IGNORE:
                 continue
-            dependency_data[task['taskType']]['statuses'].append(
-                task['status'])
+            dependency_data[task['taskType']]['statuses'].append(task['status'])
             dependency_data[task['taskType']]['errors'].append(task['error'])
-            dependency_data[task['taskType']]['messages'].append(
-                task['message'])
+            dependency_data[task['taskType']]['messages'].append(task['message'])
 
         #  Inform user that she can see error logs by passing
         #  a flag.
@@ -168,9 +161,7 @@ class BaseObservable:
         #  print that error to the terminal.
         if env.SHOW_PROCESS_STATUS_DETAILS:
             for key, value in dependency_data.items():
-                for error, message, status in zip(value['errors'],
-                                                  value['messages'],
-                                                  all_statuses):
+                for error, message, status in zip(value['errors'], value['messages'], all_statuses):
                     styled_key = style_status(TASK_CLASS_MAPPING[key], status)
                     if error:
                         for line in error.splitlines():
