@@ -37,7 +37,7 @@ class Experiment(BaseObservable):
             $runName: ID!
         ) {
             getExperiments(runName: $runName) {
-                experimentId
+                name
                 status
                 invocationCommands
                 createdAt
@@ -83,7 +83,7 @@ class Experiment(BaseObservable):
             $runName: ID!
         ) {
             getExperiments(runName: $runName) {
-                experimentId
+                name
                 status
                 invocationCommands
                 createdAt
@@ -141,12 +141,10 @@ class Experiment(BaseObservable):
             command = experiment['invocationCommands']
             base_command, *hparam_vals = get_param_values(command)
             # Get job duration - Since experiment started if running, since experiment created if queued
-            duration_str = get_experiment_duration_string(
-                created_at=experiment['createdAt'],
-                started_running_at=experiment['startedRunningAt'],
-                finished_at=experiment['finishedAt'])
-            table.add_row(experiment['experimentId'], base_command,
-                          experiment['status'], duration_str, *hparam_vals)
+            duration_str = get_experiment_duration_string(created_at=experiment['createdAt'],
+                                                          started_running_at=experiment['startedRunningAt'],
+                                                          finished_at=experiment['finishedAt'])
+            table.add_row(experiment['name'], base_command, experiment['status'], duration_str, *hparam_vals)
         return table
 
     def follow(self):
@@ -162,8 +160,7 @@ class Experiment(BaseObservable):
 
         # If no dependencies exists
         if not dependencies:
-            raise click.ClickException(
-                f"Could not find run with name {self.run_name}")
+            raise click.ClickException("Run doesn't have dependencies. Nothing to follow.")
 
         dependency_ids = []
         dependency_statuses = []
@@ -215,8 +212,7 @@ class Experiment(BaseObservable):
         #  Create a GraphQL subscription via websockect
         #  connection.
         try:
-            stream = self.client.subscribe(subscription,
-                                           variable_values=params)
+            stream = self.client.subscribe(subscription, variable_values=params)
 
             first_message = True
             for log in stream:
@@ -254,8 +250,7 @@ class Experiment(BaseObservable):
         except websockets.exceptions.ConnectionClosedOK:
             self.spinner.fail("✘")
             self.spinner.stop()
-            raise click.ClickException(
-                'Could not continue fetching log stream.')
+            raise click.ClickException('Could not continue fetching log stream.')
 
         #  Raise any other errors that the backend may raise.
         except Exception as e:  # skipcq: PYL-W0703
