@@ -105,16 +105,11 @@ class InteractiveNode(BaseObservable):
 
         #  Create progress bar.
         click.echo('\n')
-        with Progress(
-                TextColumn("[bold blue]{task.description}", justify="left"),
-                BarColumn(bar_width=55),
-                "[self.progress.percentage]{task.percentage:>3.1f}%"
-        ) as progress_bar:
+        with Progress(TextColumn("[bold blue]{task.description}", justify="left"), BarColumn(bar_width=55),
+                      "[self.progress.percentage]{task.percentage:>3.1f}%") as progress_bar:
 
             #  Render progress bar based on finished tasks.
-            task_id = progress_bar.add_task('Creating Interactive Node',
-                                            start=True,
-                                            total=len(all_status))
+            task_id = progress_bar.add_task('Creating Interactive Node', start=True, total=len(all_status))
 
             progress = sum(1 for s in all_status if s == 'finished')
             progress_bar.update(task_id, advance=progress)
@@ -129,8 +124,7 @@ class InteractiveNode(BaseObservable):
                     for line in error.splitlines():
                         click.echo(f'[{styled_key}] {line}')
                 else:
-                    styled_key = click.style(TASK_CLASS_MAPPING[key],
-                                             fg='green')
+                    styled_key = click.style(TASK_CLASS_MAPPING[key], fg='green')
                     message = value.get('message')
                     click.echo(f'[{styled_key}] {message} ... ')
 
@@ -142,8 +136,8 @@ class InteractiveNode(BaseObservable):
                 interactiveNodeId
                 interactiveNodeName
                 clusterId
-                createdAt,
-                jupyterlabUrls
+                createdAt
+                jupyterUrl
                 status
                 config {
                     diskSize
@@ -176,16 +170,11 @@ class InteractiveNode(BaseObservable):
 
         if result and result['getInteractiveNodes']:
             for row in result['getInteractiveNodes']:
-                # Fetch the first URL returned from backend.
-                # TODO: Change to use FQDN.
-                url = '-'
-                if row['jupyterlabUrls']:
-                    url = row['jupyterlabUrls'][0]
+                url = row['jupyterUrl']
 
                 # Calculate how long the interactive node has been up.
                 created_at = date_string_parse(row['createdAt'])
-                delta = get_abs_time_difference(datetime.now(timezone.utc),
-                                                created_at)
+                delta = get_abs_time_difference(datetime.now(timezone.utc), created_at)
                 duration_str = string_format_timedelta(delta)
 
                 # Add rows to table.
@@ -196,10 +185,7 @@ class InteractiveNode(BaseObservable):
 
                 # Replace anything that doesn't have data with
                 # a placeholder '-'.
-                all_rows = [
-                    row['interactiveNodeName'], status,
-                    row['config']['instanceType'], duration_str, url
-                ]
+                all_rows = [row['interactiveNodeName'], status, row['config']['instanceType'], duration_str, url]
                 all_rows = ['-' if not r else r for r in all_rows]
                 table.add_row(*all_rows)
 
@@ -212,8 +198,7 @@ class InteractiveNode(BaseObservable):
         # If there are no nodes active, add a
         # placeholder row indicating that.
         if not table_rows:
-            table.add_row("None Active.",
-                          *[" " for i in range(len(table_cols) - 1)])
+            table.add_row("None Active.", *[" " for i in range(len(table_cols) - 1)])
 
         # Print table
         self.console.print(table)
