@@ -49,9 +49,6 @@ class Run(BaseObservable):
                 nQueued
                 nPending
                 projectId
-                resourceUrls {
-                    tensorboard
-                }
             }
         }
         """)
@@ -70,8 +67,7 @@ class Run(BaseObservable):
             if env.DEBUG:
                 click.echo(str(e))
 
-            raise click.ClickException(
-                'Query to Grid failed. Try again in a few minutes.')
+            raise click.ClickException('Query to Grid failed. Try again in a few minutes.')
 
         table_cols = [
             'Run',
@@ -83,7 +79,7 @@ class Run(BaseObservable):
             'Queued',
             'Completed',
             'Failed',
-            'Cancelled',
+            'Stopped',
         ]
         table = BaseObservable.create_table(columns=table_cols)
 
@@ -120,24 +116,19 @@ class Run(BaseObservable):
 
             #  Change the printed key from `None` to `-` if the
             #  no data exists for those keys.
-            keys = [
-                'nExperiments', 'nRunning', 'nQueued', 'nCompleted', 'nFailed',
-                'nCancelled'
-            ]
+            keys = ['nExperiments', 'nRunning', 'nQueued', 'nCompleted', 'nFailed', 'nCancelled']
             for key in keys:
                 if row[key] is None:
                     row[key] = '-'
 
             # Calculate the duration column
             created_at = date_string_parse(row['createdAt'])
-            delta = get_abs_time_difference(datetime.now(timezone.utc),
-                                            created_at)
+            delta = get_abs_time_difference(datetime.now(timezone.utc), created_at)
             duration_str = string_format_timedelta(delta)
 
-            table.add_row(row['name'], row['projectId'], status, duration_str,
-                          str(row['nExperiments']), str(row['nRunning']),
-                          str(n_queued), str(row['nCompleted']),
-                          str(row['nFailed']), str(row['nCancelled']))
+            table.add_row(row['name'], row['projectId'], status, duration_str, str(row['nExperiments']),
+                          str(row['nRunning']), str(n_queued), str(row['nCompleted']), str(row['nFailed']),
+                          str(row['nCancelled']))
 
             #  Let's count how many rows have been added.
             table_rows += 1
@@ -149,8 +140,7 @@ class Run(BaseObservable):
         # If there are no Runs to render, add a
         # placeholder row indicating none are active.
         if table_rows == 0:
-            table.add_row("None Active.",
-                          *[" " for i in range(len(table_cols) - 1)])
+            table.add_row("None Active.", *[" " for i in range(len(table_cols) - 1)])
 
         self.console.print(table)
 
@@ -158,9 +148,7 @@ class Run(BaseObservable):
         #  grid history.
         history_runs = len(result['getRuns']) - table_rows
         if history_runs > 0:
-            click.echo(
-                f'\n{history_runs} Run(s) are not active. Use `grid history` '
-                'to view your Run history.')
+            click.echo(f'\n{history_runs} Run(s) are not active. Use `grid history` ' 'to view your Run history.')
 
         return result
 
@@ -203,10 +191,7 @@ class Run(BaseObservable):
         self.spinner.ok("✔")
         self.spinner.stop()
 
-        table_cols = [
-            'Run', 'Created At', 'Experiments', 'Failed', 'Cancelled',
-            'Completed'
-        ]
+        table_cols = ['Run', 'Created At', 'Experiments', 'Failed', 'Stopped', 'Completed']
         table = BaseObservable.create_table(columns=table_cols)
 
         #  Whenever we don't have yet submitted experiments,
@@ -227,17 +212,14 @@ class Run(BaseObservable):
             if is_queued or is_running:
                 continue
 
-            created_at = string_format_date(date_string_parse(
-                row['createdAt']))
+            created_at = string_format_date(date_string_parse(row['createdAt']))
 
-            table.add_row(row['name'], created_at, str(row['nExperiments']),
-                          str(row['nFailed']), str(row['nCancelled']),
-                          str(row['nCompleted']))
+            table.add_row(row['name'], created_at, str(row['nExperiments']), str(row['nFailed']),
+                          str(row['nCancelled']), str(row['nCompleted']))
 
         # Add placeholder row if no records are available.
         if not table_rows:
-            table.add_row("No History.",
-                          *[" " for i in range(len(table_cols) - 1)])
+            table.add_row("No History.", *[" " for i in range(len(table_cols) - 1)])
 
         self.console.print(table)
 
