@@ -8,8 +8,7 @@ import subprocess
 from typing import Optional, Tuple
 
 
-def get_dir_size_and_count(source_dir: str,
-                           prefix: Optional[str] = None) -> Tuple[int, int]:
+def get_dir_size_and_count(source_dir: str, prefix: Optional[str] = None) -> Tuple[int, int]:
     """
     Get size and file count of a directory
 
@@ -40,7 +39,7 @@ def get_dir_size_and_count(source_dir: str,
 @dataclass
 class TarResults:
     """
-    This class holds the results of running tar_directory.
+    This class holds the results of running tar_path.
 
     Attributes
     ----------
@@ -53,9 +52,7 @@ class TarResults:
     after_size: int
 
 
-def get_split_size(total_size: int,
-                   minimum_split_size: int = 1024 * 1000 * 20,
-                   max_split_count: int = 10000) -> int:
+def get_split_size(total_size: int, minimum_split_size: int = 1024 * 1000 * 20, max_split_count: int = 10000) -> int:
     """
     Calculate the split size we should use to split
 
@@ -82,16 +79,14 @@ def get_split_size(total_size: int,
     return split_size
 
 
-def tar_directory(source_dir: str,
-                  target_file: str,
-                  compression: bool = False) -> TarResults:
+def tar_path(source_path: str, target_file: str, compression: bool = False) -> TarResults:
     """
     Create tar from directory using `tar`
 
     Parameters
     ----------
-    source_dir: str
-        Source directory
+    source_path: str
+        Source directory or file
     target_file
         Target tar file
     compression: bool, default False
@@ -103,7 +98,10 @@ def tar_directory(source_dir: str,
     TarResults
         Results that holds file counts and sizes
     """
-    before_size, _ = get_dir_size_and_count(source_dir)
+    if os.path.isdir(source_path):
+        before_size, _ = get_dir_size_and_count(source_path)
+    else:
+        before_size = os.path.getsize(source_path)
 
     # Only add compression when users explicitly request it.
     # We do this because it takes too long to compress
@@ -111,8 +109,14 @@ def tar_directory(source_dir: str,
     tar_flags = '-cvf'
     if compression:
         tar_flags = '-zcvf'
+    if os.path.isdir(source_path):
+        command = f"tar -C {source_path} {tar_flags} {target_file} ./"
+    else:
+        abs_path = os.path.abspath(source_path)
+        parent_dir = os.path.dirname(abs_path)
+        base_name = os.path.basename(abs_path)
+        command = f"tar -C {parent_dir} {tar_flags} {target_file} {base_name}"
 
-    command = f"tar -C {source_dir} {tar_flags} {target_file} ./"
     subprocess.check_call(command,
                           stdout=subprocess.DEVNULL,
                           stderr=subprocess.DEVNULL,
