@@ -4,12 +4,11 @@ Uploader that uploads files into Cloud storage
 
 from concurrent.futures import as_completed
 from concurrent.futures import ThreadPoolExecutor
-from typing import AnyStr, Dict, IO, List
+from typing import AnyStr, Dict, List
 
 import requests
 from requests.adapters import HTTPAdapter
 from rich.progress import BarColumn
-from rich.progress import DownloadColumn
 from rich.progress import Progress
 from rich.progress import TextColumn
 from urllib3.util.retry import Retry
@@ -53,10 +52,8 @@ class S3Uploader:
     retries: int = 10000
     backoff_factor: float = 1.
 
-    progress = Progress(
-        TextColumn("[bold blue]{task.description}", justify="left"),
-        BarColumn(bar_width=None),
-        "[self.progress.percentage]{task.percentage:>3.1f}%")
+    progress = Progress(TextColumn("[bold blue]{task.description}", justify="left"), BarColumn(bar_width=None),
+                        "[self.progress.percentage]{task.percentage:>3.1f}%")
 
     def __init__(self,
                  presigned_urls: Dict[int, str],
@@ -75,8 +72,7 @@ class S3Uploader:
         self.progress_callback = progress_callback
 
     @staticmethod
-    def upload_s3_data(url: str, data: bytes, retries: int,
-                       backoff_factor: float) -> str:
+    def upload_s3_data(url: str, data: bytes, retries: int, backoff_factor: float) -> str:
         """
         Send data to s3 url
 
@@ -97,14 +93,11 @@ class S3Uploader:
             ETag from response
         """
         s = requests.Session()
-        retries = Retry(total=retries,
-                        backoff_factor=backoff_factor,
-                        status_forcelist=[500, 502, 503, 504])
+        retries = Retry(total=retries, backoff_factor=backoff_factor, status_forcelist=[500, 502, 503, 504])
         s.mount('http://', HTTPAdapter(max_retries=retries))
         response = s.put(url, data=data)
         if 'ETag' not in response.headers:
-            raise ValueError(
-                f"Unexpected response from S3, response: {response.content}")
+            raise ValueError(f"Unexpected response from S3, response: {response.content}")
 
         return response.headers['ETag']
 
@@ -146,8 +139,7 @@ class S3Uploader:
 
             self.progress.update(task_id, advance=len(data))
 
-    def _upload_part(self, url: str, part_path: str, part: int,
-                     task_id: str) -> None:
+    def _upload_part(self, url: str, part_path: str, part: int, task_id: str) -> None:
         """
         Upload part of the data file with presigned url
 
@@ -167,8 +159,7 @@ class S3Uploader:
             f.seek(pos)
             data = f.read(self.split_size)
 
-        etag = self.upload_s3_data(url, data, self.retries,
-                                   self.backoff_factor)
+        etag = self.upload_s3_data(url, data, self.retries, self.backoff_factor)
         self.progress.update(task_id, advance=len(data))
         if self.progress_callback:
             self.progress_callback.upload_part_completed(part=part, etag=etag)
@@ -177,9 +168,7 @@ class S3Uploader:
         """
         Upload files from source dir into target path in S3
         """
-        task_id = self.progress.add_task("upload",
-                                         filename=self.name,
-                                         total=self.total_size)
+        task_id = self.progress.add_task("upload", filename=self.name, total=self.total_size)
         with ThreadPoolExecutor(max_workers=self.workers) as pool:
             try:
                 self.progress.start()
@@ -193,8 +182,7 @@ class S3Uploader:
                         future.result()
 
                 for part, url in self.presigned_urls.items():
-                    f = pool.submit(self._upload_part, url, self.source_file,
-                                    part, task_id)
+                    f = pool.submit(self._upload_part, url, self.source_file, part, task_id)
                     futures.append(f)
 
                     for future in as_completed(futures):
