@@ -17,6 +17,7 @@ from dateutil.parser import parse as date_string_parse
 from google.cloud import storage
 import pytz
 from tzlocal import get_localzone
+import ulid
 
 from grid import autocomplete
 
@@ -29,16 +30,14 @@ class GCPStorage:  # pragma: no cover
     def __init__(self):
         self.storage_client = storage.Client()
 
-    def upload_blob(self, bucket_name, source_file_name,
-                    destination_blob_name):
+    def upload_blob(self, bucket_name, source_file_name, destination_blob_name):
         """Uploads a file to the bucket."""
         bucket = self.storage_client.bucket(bucket_name)
         blob = bucket.blob(destination_blob_name)
 
         blob.upload_from_filename(source_file_name)
 
-        print("File {} uploaded to {}.".format(source_file_name,
-                                               destination_blob_name))
+        print("File {} uploaded to {}.".format(source_file_name, destination_blob_name))
 
     def delete_blob(self, bucket_name, blob_name):
         """Deletes a blob from the bucket."""
@@ -60,20 +59,14 @@ class GCPStorage:  # pragma: no cover
 
     def list_blobs(self, bucket_name, prefix='', delimiter=None):
         """Lists all the blobs in the bucket."""
-        blobs = self.storage_client.list_blobs(bucket_name,
-                                               prefix=prefix,
-                                               delimiter=delimiter)
+        blobs = self.storage_client.list_blobs(bucket_name, prefix=prefix, delimiter=delimiter)
 
         names = []
         for blob in blobs:
             names.append(blob.name)
         return names
 
-    def download_blob(self,
-                      bucket_name,
-                      source_blob_name,
-                      destination_file_name,
-                      source_blob_prefix=''):
+    def download_blob(self, bucket_name, source_blob_name, destination_file_name, source_blob_prefix=''):
         """Downloads a blob from the bucket."""
         bucket = self.storage_client.bucket(bucket_name)
         blobs = bucket.list_blobs()
@@ -129,8 +122,7 @@ def string_format_timedelta(delta: timedelta) -> str:
     return delta_str
 
 
-def upload_wheel(gcp_storage, version, bucket_name,
-                 blob_path):  # pragma: no cover
+def upload_wheel(gcp_storage, version, bucket_name, blob_path):  # pragma: no cover
     """
     Uploads wheel to it's designated GCP bucket.
     """
@@ -145,8 +137,7 @@ def upload_wheel(gcp_storage, version, bucket_name,
         version_path = f"{blob_path}/{version}/{wheel}"
 
         # delete existing object in "latest" directory
-        gcp_storage.delete_blobs(bucket_name=bucket_name,
-                                 prefix=f'{blob_path}/latest/')
+        gcp_storage.delete_blobs(bucket_name=bucket_name, prefix=f'{blob_path}/latest/')
 
         gcp_storage.upload_blob(bucket_name=bucket_name,
                                 source_file_name=f'dist/{wheel}',
@@ -175,8 +166,7 @@ def check_environment_variables(variables: list) -> bool:
     """
     for variable in variables:
         if not os.getenv(variable):
-            raise ValueError(
-                f'Environment variable `{variable}` has not been set.')
+            raise ValueError(f'Environment variable `{variable}` has not been set.')
 
     return True
 
@@ -203,12 +193,13 @@ def introspect_module(module: ModuleType):
 
 def is_experiment(identifier: str) -> bool:
     """
-    Checks if identifier is an Experiment.
+    Checks if identifier is an Experiment. The check is done
+    both against experiment names and experiments IDs (ULIDs).
 
     Parameters
     ----------
     identifier: str
-        Run or Experiment identifier to check.
+        Experiment identifier to check.
 
     Returns
     -------
@@ -218,11 +209,17 @@ def is_experiment(identifier: str) -> bool:
     regex = re.compile(r'exp[0-9]+$')
     result = regex.search(identifier)
 
-    output = False
+    is_experiment_name = False
     if result:
-        output = True
+        is_experiment_name = True
 
-    return output
+    try:
+        ulid.from_str(identifier)
+        is_experiment_id = True
+    except ValueError:
+        is_experiment_id = False
+
+    return is_experiment_name or is_experiment_id
 
 
 def get_param_values(command: str) -> List[str]:
@@ -253,8 +250,7 @@ def get_param_values(command: str) -> List[str]:
     return hparam_vals
 
 
-def get_experiment_duration_string(created_at: str, started_running_at: str,
-                                   finished_at: str):
+def get_experiment_duration_string(created_at: str, started_running_at: str, finished_at: str):
     """
     Calculates:
     - If experiment still queued: between experiment creation and now
@@ -262,13 +258,9 @@ def get_experiment_duration_string(created_at: str, started_running_at: str,
     - If experiment finished, between start of run and end
     """
 
-    end = datetime.now(
-        timezone.utc) if finished_at is None else date_string_parse(
-            finished_at)
+    end = datetime.now(timezone.utc) if finished_at is None else date_string_parse(finished_at)
 
-    start = date_string_parse(
-        created_at) if started_running_at is None else date_string_parse(
-            started_running_at)
+    start = date_string_parse(created_at) if started_running_at is None else date_string_parse(started_running_at)
 
     delta = get_abs_time_difference(end, start)
     return string_format_timedelta(delta)
@@ -287,16 +279,14 @@ def get_graphql_url(url: str) -> str:
     -------
     A url appended with graphql if not already included
     """
-    return url if parse.urlparse(url).path.endswith(
-        '/graphql') else parse.urljoin(url, "/graphql")
+    return url if parse.urlparse(url).path.endswith('/graphql') else parse.urljoin(url, "/graphql")
 
 
 def check_is_python_script(ctx, _param, value):
     """Click callback that checks if a file is a Python script."""
     if value is not None:
         if not value.endswith('.py'):
-            raise click.BadParameter('You must provide a Python script. '
-                                     'No script detected.')
+            raise click.BadParameter('You must provide a Python script. ' 'No script detected.')
 
         ctx.params['entrypoint'] = value
         return value
@@ -305,8 +295,7 @@ def check_is_python_script(ctx, _param, value):
 def check_description_isnt_too_long(ctx, _param, value):
     """Click callback that checks if the description isn't too long."""
     if value is not None and len(value) > 200:
-        raise click.BadParameter('Description should have at most '
-                                 f'200 characters. Yous has {len(value)}.')
+        raise click.BadParameter('Description should have at most ' f'200 characters. Yous has {len(value)}.')
     return value
 
 
@@ -326,16 +315,11 @@ def install_autocomplete() -> None:
 
     complete.mkdir(parents=True, exist_ok=True)
 
-    bash_complete.write_text(
-        pkg_resources.read_text(autocomplete, "complete.bash"))
-    zsh_complete.write_text(
-        pkg_resources.read_text(autocomplete, "complete.zsh"))
+    bash_complete.write_text(pkg_resources.read_text(autocomplete, "complete.bash"))
+    zsh_complete.write_text(pkg_resources.read_text(autocomplete, "complete.zsh"))
 
     for rc, sh_complete in zip([bashrc, zshrc], [bash_complete, zsh_complete]):
         # Adds necessary activation to shell config if the file exists and doesn't already contain
         if rc.exists() and str(sh_complete) not in rc.read_text():
             with rc.open("a") as f:
-                f.write(
-                    "\n# Grid Autocomplete\n"
-                    f"if [ -f '{sh_complete}' ]; then . '{sh_complete}' ; fi\n"
-                )
+                f.write("\n# Grid Autocomplete\n" f"if [ -f '{sh_complete}' ]; then . '{sh_complete}' ; fi\n")
