@@ -25,23 +25,21 @@ class TestDelete:
 
     def test_delete_deletes_runs_and_experiments(self):
         """grid delete fails without arguments"""
-        run_id = 'test-run'
-        result = RUNNER.invoke(cli.delete, ["run", run_id], input='y\n')
+        result = RUNNER.invoke(cli.delete, ["run", 'test-run'], input='y\n')
         assert result.exit_code == 0
         assert not result.exception
         assert 'Are you sure you want to do this?' in result.output
+        assert 'deleted successfully' in result.output
 
-        experiment_id = 'test-run-exp0'
-        result = RUNNER.invoke(cli.delete, ["experiment", experiment_id],
-                               input='y\n')
+        result = RUNNER.invoke(cli.delete, ["experiment", 'test-run-exp0'], input='y\n')
         assert result.exit_code == 0
         assert not result.exception
         assert 'Are you sure you want to do this?' in result.output
+        assert 'deleted successfully' in result.output
 
     def test_delete_deletes_warning_prevents_delete(self):
         """grid delete warning prevents a deletion"""
-        run_id = 'test-run'
-        result = RUNNER.invoke(cli.delete, ["run", run_id], input='N\n')
+        result = RUNNER.invoke(cli.delete, ["run", 'test-run'], input='N\n')
         assert result.exit_code == 1
         assert 'Are you sure you want to do this?' in result.output
 
@@ -51,11 +49,10 @@ class TestDelete:
             return {"success": False}
 
         monkeypatch.setattr(resolvers, 'delete_run', delete_run)
-        run_id = 'test-run'
-        result = RUNNER.invoke(cli.delete, ["run", run_id], input='y\n')
+        result = RUNNER.invoke(cli.delete, ["run", 'test-run'], input='y\n')
         assert result.exit_code == 1
         assert result.exception
-        assert 'Failed to delete run' in result.output
+        assert 'Delete failed' in result.output
 
     def test_delete_run_fails_with_exception(self, monkeypatch):
         """grid delete run fails with exception"""
@@ -63,11 +60,10 @@ class TestDelete:
             raise Exception()
 
         monkeypatch.setattr(resolvers, 'delete_run', delete_run)
-        run_id = 'test-run'
-        result = RUNNER.invoke(cli.delete, ["run", run_id], input='y\n')
+        result = RUNNER.invoke(cli.delete, ["run", 'test-run'], input='y\n')
         assert result.exit_code == 1
         assert result.exception
-        assert 'Failed to delete run' in result.output
+        assert 'Delete failed' in result.output
 
     def test_delete_experiment_fails(self, monkeypatch):
         """grid delete experiment fails"""
@@ -75,12 +71,10 @@ class TestDelete:
             return {"success": False}
 
         monkeypatch.setattr(resolvers, 'delete_experiment', delete_experiment)
-        experiment_id = 'test-run-exp0'
-        result = RUNNER.invoke(cli.delete, ["experiment", experiment_id],
-                               input='y\n')
+        result = RUNNER.invoke(cli.delete, ["experiment", 'test-run-exp0'], input='y\n')
         assert result.exit_code == 1
         assert result.exception
-        assert 'Failed to delete experiment' in result.output
+        assert 'Delete failed' in result.output
 
     def test_delete_experiment_fails_with_exception(self, monkeypatch):
         """grid delete experiment fails with exception"""
@@ -88,9 +82,29 @@ class TestDelete:
             raise Exception()
 
         monkeypatch.setattr(resolvers, 'delete_experiment', delete_experiment)
-        experiment_id = 'test-run-exp0'
-        result = RUNNER.invoke(cli.delete, ["experiment", experiment_id],
-                               input='y\n')
+        result = RUNNER.invoke(cli.delete, ["experiment", 'test-run-exp0'], input='y\n')
         assert result.exit_code == 1
         assert result.exception
-        assert 'Failed to delete experiment' in result.output
+        assert 'Delete failed' in result.output
+
+    def test_delete_experiment_fails_when_experiment_not_found(self, monkeypatch):
+        def mp_get_experiment_id(*args, **kwargs):
+            return {"success": False}
+
+        monkeypatch.setattr(resolvers, 'get_experiment_id', mp_get_experiment_id)
+        result = RUNNER.invoke(cli.delete, ["experiment", 'test-run-exp0'], input='y\n')
+        assert result.exit_code == 1
+        assert result.exception
+        assert 'Delete failed' in result.output
+        assert 'Could not find experiment' in result.output
+
+    def test_delete_experiment_fails_when_experiment_not_found_exception(self, monkeypatch):
+        def mp_get_experiment_id(*args, **kwargs):
+            raise Exception()
+
+        monkeypatch.setattr(resolvers, 'get_experiment_id', mp_get_experiment_id)
+        result = RUNNER.invoke(cli.delete, ["experiment", 'test-run-exp0'], input='y\n')
+        assert result.exit_code == 1
+        assert result.exception
+        assert 'Delete failed' in result.output
+        assert 'Could not find experiment' in result.output
