@@ -1,3 +1,5 @@
+from unittest.mock import patch
+
 from click.testing import CliRunner
 from tests.mock_backend import resolvers
 from tests.utilities import monkey_patch_client
@@ -36,8 +38,7 @@ class TestInteractive:
             return {'success': True, 'message': ''}
 
         monkeypatch.setattr(grid.Grid, 'status', self.mp_status)
-        monkeypatch.setattr(resolvers, 'create_interactive_node',
-                            mp_create_interactive_node)
+        monkeypatch.setattr(resolvers, 'create_interactive_node', mp_create_interactive_node)
 
         result = RUNNER.invoke(cli.interactive, ["create"])
         assert result.exit_code == 0
@@ -69,8 +70,7 @@ class TestInteractive:
                 }]
             }
 
-        monkeypatch.setattr(grid.Grid, 'get_credentials',
-                            mp_get_credentials_multiple_no_default)
+        monkeypatch.setattr(grid.Grid, 'get_credentials', mp_get_credentials_multiple_no_default)
         result = RUNNER.invoke(cli.interactive, ["create"])
         assert result.exit_code == 1
         assert result.exception
@@ -90,9 +90,7 @@ class TestInteractive:
             }
 
         monkeypatch.setattr(grid.Grid, 'get_credentials', mp_no_default_creds)
-        result = RUNNER.invoke(
-            cli.interactive,
-            ["create", '--grid_credential', self.CREDENTIAL_ID])
+        result = RUNNER.invoke(cli.interactive, ["create", '--grid_credential', self.CREDENTIAL_ID])
         assert result.exit_code == 1
         assert result.exception
         assert f'Credential ID {self.CREDENTIAL_ID} does not exist.' in result.output
@@ -118,13 +116,7 @@ class TestInteractive:
         creds = self.CREDENTIAL_ID
 
         def mp_default_creds(self):
-            return {
-                'getUserCredentials': [{
-                    'credentialId': creds,
-                    'provider': 'aws',
-                    'defaultCredential': True
-                }]
-            }
+            return {'getUserCredentials': [{'credentialId': creds, 'provider': 'aws', 'defaultCredential': True}]}
 
         monkeypatch.setattr(grid.Grid, 'get_credentials', mp_default_creds)
         result = RUNNER.invoke(cli.interactive, ["create"])
@@ -136,15 +128,13 @@ class TestInteractive:
     def test_interactive_create_fails_if_config_not_found():
         """grid interactive create fails if config not found"""
 
-        result = RUNNER.invoke(cli.interactive,
-                               ["create", "--grid_config", "no-file"])
+        result = RUNNER.invoke(cli.interactive, ["create", "--grid_config", "no-file"])
 
         assert result.exit_code == 2
         assert result.exception
         assert 'Could not open file' in result.output
 
-    def test_interactive_create_succeeds_with_config(self, tmp_path,
-                                                     monkeypatch):
+    def test_interactive_create_succeeds_with_config(self, tmp_path, monkeypatch):
         """grid interactive create succeeds with config"""
         content = """
         compute:
@@ -167,9 +157,7 @@ class TestInteractive:
         config.write_text(content)
 
         monkeypatch.setattr(grid.Grid, 'status', self.mp_status)
-        result = RUNNER.invoke(cli.interactive,
-                               ["create", "--grid_config",
-                                config.as_posix()])
+        result = RUNNER.invoke(cli.interactive, ["create", "--grid_config", config.as_posix()])
 
         assert result.exit_code == 0
         assert not result.exception
@@ -181,8 +169,7 @@ class TestInteractive:
         def mp_delete_interactive_node(*args, **kwargs):
             return {'success': True, 'message': ''}
 
-        monkeypatch.setattr(resolvers, 'delete_interactive_node',
-                            mp_delete_interactive_node)
+        monkeypatch.setattr(resolvers, 'delete_interactive_node', mp_delete_interactive_node)
         result = RUNNER.invoke(cli.interactive, ["delete", "node-to-delete"])
 
         assert result.exit_code == 0
@@ -195,8 +182,7 @@ class TestInteractive:
         def mp_delete_interactive_node(*args, **kwargs):
             return {'success': False, 'message': ''}
 
-        monkeypatch.setattr(resolvers, 'delete_interactive_node',
-                            mp_delete_interactive_node)
+        monkeypatch.setattr(resolvers, 'delete_interactive_node', mp_delete_interactive_node)
         result = RUNNER.invoke(cli.interactive, ["delete", "node-to-delete"])
 
         assert result.exit_code == 1
@@ -211,12 +197,44 @@ class TestInteractive:
             return {'success': True, 'message': ''}
 
         monkeypatch.setattr(grid.Grid, 'status', self.mp_status)
-        monkeypatch.setattr(resolvers, 'create_interactive_node',
-                            mp_create_interactive_node)
+        monkeypatch.setattr(resolvers, 'create_interactive_node', mp_create_interactive_node)
 
-        result = RUNNER.invoke(
-            cli.interactive,
-            ["create", "--grid_description", "test-description"])
+        result = RUNNER.invoke(cli.interactive, ["create", "--grid_description", "test-description"])
+        assert result.exit_code == 0
+        assert not result.exception
+        assert 'Interactive node created!' in result.output
+
+    @patch("grid.client.Grid.sync_ssh_config",
+           autospec=True,
+           return_value=[
+               {
+                   "name": "test-pending",
+                   "ssh_url": "ssh://jovyan@ix2.grid.ai:433",
+                   "status": "pending",
+               },
+           ])
+    def test_update_ssh_config_and_check_ixsession_status_callback(self, ixsessions):
+        result = RUNNER.invoke(cli.interactive, ["ssh", "not-exist-test"])
+        assert result.exit_code == 2
+        assert result.output
+        assert "does not exist" in result.output
+
+        result = RUNNER.invoke(cli.interactive, ["ssh", "test-pending"])
+        assert result.exit_code == 2
+        assert result.output
+        assert "not ready" in result.output
+
+    def test_session_with_nickname(self, monkeypatch):
+        """
+        grid interactive create succeeds with nickname
+        """
+        def mp_create_interactive_node(*args, **kwargs):
+            return {'success': True, 'message': ''}
+
+        monkeypatch.setattr(grid.Grid, 'status', self.mp_status)
+        monkeypatch.setattr(resolvers, 'create_interactive_node', mp_create_interactive_node)
+
+        result = RUNNER.invoke(cli.interactive, ["create", '--grid_instance_type', '2_cpu_4gb'])
         assert result.exit_code == 0
         assert not result.exception
         assert 'Interactive node created!' in result.output
