@@ -8,7 +8,7 @@ from tests import resolvers
 from tests.mock_backend import GridAIBackenedTestServer
 
 from grid import cli
-from grid import Grid
+from grid.client import Grid
 import grid.client as grid
 
 logger = logging.getLogger()
@@ -34,9 +34,7 @@ class TestSSHKey:
             key_path_pub = Path(tmpdirname) / "id_ed25519.pub"
             key_path_pub.write_text(key_pub)
 
-            key_id = invoke(
-                'add', "my key",
-                str(key_path_pub))[len('Added key with id: '):].strip()
+            key_id = invoke('add', "my key", str(key_path_pub))[len('Added key with id: '):].strip()
             logger.info(f"key_id {key_id}")
             invoke('list')
             invoke('authorized_keys')
@@ -63,12 +61,11 @@ class TestSSHKey:
 
     @staticmethod
     def test_add_ssh_key(monkeypatch):
-        resolver = MagicMock(
-            return_value={
-                "message": "ok",
-                "success": True,
-                "id": "8156af4e-b7fc-466f-9cbf-a3db840fff45",
-            })
+        resolver = MagicMock(return_value={
+            "message": "ok",
+            "success": True,
+            "id": "8156af4e-b7fc-466f-9cbf-a3db840fff45",
+        })
 
         def monkey_patch_client(x):
             x.client = GridAIBackenedTestServer()
