@@ -17,13 +17,7 @@ CONTENT = "content"
 
 # Monkey patches the getting of credentials
 def monkey_patch_get_credentials(self):
-    return {
-        'getUserCredentials': [{
-            'credentialId': CREDENTIAL_ID,
-            'provider': 'aws',
-            'defaultCredential': True
-        }]
-    }
+    return {'getUserCredentials': [{'credentialId': CREDENTIAL_ID, 'provider': 'aws', 'defaultCredential': True}]}
 
 
 def monkey_patch_get_credentials_multiple(self):
@@ -72,13 +66,7 @@ def monkey_patch_no_creds(self):
 
 #  Monkey patch the client.
 def monkey_patch_wrong_creds(self):
-    return {
-        'getUserCredentials': [{
-            'credentialId': 'wrong-cred',
-            'provider': 'aws',
-            'defaultCredential': True
-        }]
-    }
+    return {'getUserCredentials': [{'credentialId': 'wrong-cred', 'provider': 'aws', 'defaultCredential': True}]}
 
 
 def monkey_patch_github_accessible(self, _):
@@ -98,10 +86,8 @@ def test_train_fails_with_no_arguments(monkeypatch):
     """grid train without arguments fails"""
     monkeypatch.setattr(grid.Grid, '_init_client', monkey_patch_client)
 
-    monkeypatch.setattr(grid.Grid, 'get_credentials',
-                        monkey_patch_get_credentials)
-    monkeypatch.setattr(grid.Grid, '_check_user_github_token',
-                        monkey_patch_token_check)
+    monkeypatch.setattr(grid.Grid, 'get_credentials', monkey_patch_get_credentials)
+    monkeypatch.setattr(grid.Grid, '_check_user_github_token', monkey_patch_token_check)
 
     result = RUNNER.invoke(cli.train, [])
     assert result.exit_code == 2
@@ -112,8 +98,7 @@ def test_train_fails_with_no_credentials(monkeypatch):
     """grid train fails if user has no credentials."""
     monkeypatch.setattr(grid.Grid, 'get_credentials', monkey_patch_no_creds)
     monkeypatch.setattr(grid.Grid, '_set_local_credentials', lambda x: True)
-    monkeypatch.setattr(grid.Grid, '_check_user_github_token',
-                        monkey_patch_token_check)
+    monkeypatch.setattr(grid.Grid, '_check_user_github_token', monkey_patch_token_check)
 
     result = RUNNER.invoke(cli.train, ['--', 'tests/data/script.py'])
 
@@ -124,13 +109,10 @@ def test_train_fails_with_no_credentials(monkeypatch):
 def test_train_fails_if_credentials_dont_exist(monkeypatch):
     """grid train fails if credentials don't exist for user."""
     monkeypatch.setattr(grid.Grid, '_set_local_credentials', lambda x: True)
-    monkeypatch.setattr(grid.Grid, '_check_user_github_token',
-                        monkey_patch_token_check)
+    monkeypatch.setattr(grid.Grid, '_check_user_github_token', monkey_patch_token_check)
 
-    result = RUNNER.invoke(cli.train, [
-        '--grid_credential', 'test-fail', '--grid_cpus', 1, '--',
-        'tests/data/script.py'
-    ])
+    result = RUNNER.invoke(cli.train,
+                           ['--grid_credential', 'test-fail', '--grid_cpus', 1, '--', 'tests/data/script.py'])
 
     assert result.exit_code == 1
     assert result.exception
@@ -142,9 +124,7 @@ def test_train_fails_if_wrong_credential(monkeypatch):
 
     monkeypatch.setattr(grid.Grid, 'get_credentials', monkey_patch_wrong_creds)
 
-    result = RUNNER.invoke(
-        cli.train,
-        ['--grid_credential', CREDENTIAL_ID, '--', 'tests/data/script.py'])
+    result = RUNNER.invoke(cli.train, ['--grid_credential', CREDENTIAL_ID, '--', 'tests/data/script.py'])
 
     assert result.exit_code == 1
     assert result.exception
@@ -155,8 +135,7 @@ def test_train_fails_with_multiple_non_default_credentials(monkeypatch):
     """grid train fails if multiple non default credentials."""
     monkeypatch.setattr(grid.Grid, '_init_client', monkey_patch_client)
 
-    monkeypatch.setattr(grid.Grid, 'get_credentials',
-                        monkey_patch_get_credentials_multiple_no_default)
+    monkeypatch.setattr(grid.Grid, 'get_credentials', monkey_patch_get_credentials_multiple_no_default)
 
     result = RUNNER.invoke(cli.train, ['--', 'tests/data/script.py'])
 
@@ -169,13 +148,10 @@ def test_train_fails_if_config_not_found(tmp_path, monkeypatch):
     """grid train fails if config not found"""
     monkeypatch.setattr(grid.Grid, '_init_client', monkey_patch_client)
 
-    monkeypatch.setattr(grid.Grid, 'get_credentials',
-                        monkey_patch_get_credentials)
+    monkeypatch.setattr(grid.Grid, 'get_credentials', monkey_patch_get_credentials)
 
-    result = RUNNER.invoke(cli.train, [
-        '--grid_credential', CREDENTIAL_ID, '--grid_config', 'no-file',
-        'tests/data/script.py'
-    ])
+    result = RUNNER.invoke(cli.train,
+                           ['--grid_credential', CREDENTIAL_ID, '--grid_config', 'no-file', 'tests/data/script.py'])
 
     assert result.exit_code == 2
     assert result.exception
@@ -186,8 +162,7 @@ def test_train_fails_with_bad_config(tmp_path, monkeypatch):
     """grid train fails with bad config"""
     monkeypatch.setattr(grid.Grid, '_init_client', monkey_patch_client)
 
-    monkeypatch.setattr(grid.Grid, 'get_credentials',
-                        monkey_patch_get_credentials)
+    monkeypatch.setattr(grid.Grid, 'get_credentials', monkey_patch_get_credentials)
 
     bad_yamls = [
         """
@@ -204,10 +179,10 @@ def test_train_fails_with_bad_config(tmp_path, monkeypatch):
         bad_config = tmp_path / f"bad_config_{i}.yaml"
         bad_config.write_text(content)
 
-        result = RUNNER.invoke(cli.train, [
-            '--grid_credential', CREDENTIAL_ID, '--grid_config',
-            bad_config.as_posix(), '--', 'tests/data/script.py'
-        ])
+        result = RUNNER.invoke(
+            cli.train,
+            ['--grid_credential', CREDENTIAL_ID, '--grid_config',
+             bad_config.as_posix(), '--', 'tests/data/script.py'])
 
         assert result.exit_code == 2
         assert result.exception
@@ -218,8 +193,7 @@ def test_train_fails_with_incomplete_config(tmp_path, monkeypatch):
     """grid train fails with incomplete config"""
     monkeypatch.setattr(grid.Grid, '_init_client', monkey_patch_client)
 
-    monkeypatch.setattr(grid.Grid, 'get_credentials',
-                        monkey_patch_get_credentials)
+    monkeypatch.setattr(grid.Grid, 'get_credentials', monkey_patch_get_credentials)
 
     bad_yamls = [
         """
@@ -297,8 +271,8 @@ def test_train_fails_if_description_is_too_long(monkeypatch):
     """grid train fails if description is too long."""
     description = 201 * '-'  #  200 characters is the limit.
     result = RUNNER.invoke(cli.train, [
-        '--grid_description', description, '--grid_credential', CREDENTIAL_ID,
-        '--grid_cpus', 1, '--', 'tests/data/script.py'
+        '--grid_description', description, '--grid_credential', CREDENTIAL_ID, '--grid_cpus', 1, '--',
+        'tests/data/script.py'
     ])
     assert result.exit_code == 2
     assert result.exception
@@ -309,11 +283,9 @@ def test_train_fails_if_run_name_fails_validation(monkeypatch):
     run_name = "RUN"  # capital letters not allowed in run name
     monkeypatch.setattr(grid.Grid, '_init_client', monkey_patch_client)
 
-    monkeypatch.setattr(grid.Grid, 'get_credentials',
-                        monkey_patch_get_credentials)
+    monkeypatch.setattr(grid.Grid, 'get_credentials', monkey_patch_get_credentials)
     monkeypatch.setattr(grid.Grid, '_set_local_credentials', lambda x: True)
-    monkeypatch.setattr(grid.Grid, '_check_user_github_token',
-                        monkey_patch_token_check)
+    monkeypatch.setattr(grid.Grid, '_check_user_github_token', monkey_patch_token_check)
 
     result = RUNNER.invoke(cli.train, [
         '--grid_credential',
@@ -334,13 +306,10 @@ def test_train_default_cred(monkeypatch):
     monkeypatch.setattr(grid, 'gql', lambda x: x)
     monkeypatch.setattr(grid.Grid, '_init_client', monkey_patch_client)
 
-    monkeypatch.setattr(grid.Grid, 'get_credentials',
-                        monkey_patch_get_credentials_multiple)
-    monkeypatch.setattr(grid.Grid, '_check_github_repo_accessible',
-                        monkey_patch_github_accessible)
+    monkeypatch.setattr(grid.Grid, 'get_credentials', monkey_patch_get_credentials_multiple)
+    monkeypatch.setattr(grid.Grid, '_check_github_repo_accessible', monkey_patch_github_accessible)
 
-    result = RUNNER.invoke(cli.train,
-                           ['--ignore_warnings', 'tests/data/script.py'])
+    result = RUNNER.invoke(cli.train, ['--ignore_warnings', 'tests/data/script.py'])
 
     assert result.exit_code == 0
     assert not result.exception
@@ -360,21 +329,16 @@ def test_train_fails_if_github_repo_not_accessible(monkeypatch):
     monkeypatch.setattr(grid, 'gql', lambda x: x)
     monkeypatch.setattr(grid.Grid, '_init_client', monkey_patch_client)
 
-    monkeypatch.setattr(grid.Grid, 'get_credentials',
-                        monkey_patch_get_credentials)
-    monkeypatch.setattr(grid.Grid, '_check_user_github_token',
-                        monkey_patch_token_check)
-    monkeypatch.setattr(grid.Grid, '_check_github_repo_accessible',
-                        monkey_patch_github_not_accessible)
+    monkeypatch.setattr(grid.Grid, 'get_credentials', monkey_patch_get_credentials)
+    monkeypatch.setattr(grid.Grid, '_check_user_github_token', monkey_patch_token_check)
+    monkeypatch.setattr(grid.Grid, '_check_github_repo_accessible', monkey_patch_github_not_accessible)
     monkeypatch.setattr(click, 'launch', mp_launch)
-    result = RUNNER.invoke(cli.train,
-                           ['--ignore_warnings', 'tests/data/script.py'])
+    result = RUNNER.invoke(cli.train, ['--ignore_warnings', 'tests/data/script.py'])
 
     assert result.exit_code == 1
     assert result.exception
     assert 'Please grant access on the settings page' in result.output
-    assert launch_url == os.getenv('GRID_URL', env.DEFAULT_GRID_URL).replace(
-        "/graphql", "") + '/#/settings'
+    assert launch_url == os.getenv('GRID_URL', env.DEFAULT_GRID_URL).replace("/graphql", "") + '/#/settings'
 
 
 def test_train_fails_no_ignore_warnings(monkeypatch):
@@ -382,16 +346,12 @@ def test_train_fails_no_ignore_warnings(monkeypatch):
     monkeypatch.setattr(grid, 'gql', lambda x: x)
     monkeypatch.setattr(grid.Grid, '_init_client', monkey_patch_client)
 
-    monkeypatch.setattr(grid.Grid, 'get_credentials',
-                        monkey_patch_get_credentials)
+    monkeypatch.setattr(grid.Grid, 'get_credentials', monkey_patch_get_credentials)
     monkeypatch.setattr(grid.Grid, '_set_local_credentials', lambda x: True)
-    monkeypatch.setattr(grid.Grid, '_check_user_github_token',
-                        monkey_patch_token_check)
+    monkeypatch.setattr(grid.Grid, '_check_user_github_token', monkey_patch_token_check)
 
     env.DEBUG = True
-    result = RUNNER.invoke(
-        cli.train,
-        ['--grid_credential', CREDENTIAL_ID, 'tests/data/script.py'])
+    result = RUNNER.invoke(cli.train, ['--grid_credential', CREDENTIAL_ID, 'tests/data/script.py'])
 
     #assert result.exit_code == 0
     #assert not result.exception
@@ -403,20 +363,36 @@ def test_train(monkeypatch):
     monkeypatch.setattr(grid, 'gql', lambda x: x)
     monkeypatch.setattr(grid.Grid, '_init_client', monkey_patch_client)
 
-    monkeypatch.setattr(grid.Grid, 'get_credentials',
-                        monkey_patch_get_credentials)
+    monkeypatch.setattr(grid.Grid, 'get_credentials', monkey_patch_get_credentials)
     monkeypatch.setattr(grid.Grid, '_set_local_credentials', lambda x: True)
-    monkeypatch.setattr(grid.Grid, '_check_user_github_token',
-                        monkey_patch_token_check)
-    monkeypatch.setattr(grid.Grid, '_check_github_repo_accessible',
-                        monkey_patch_github_accessible)
+    monkeypatch.setattr(grid.Grid, '_check_user_github_token', monkey_patch_token_check)
+    monkeypatch.setattr(grid.Grid, '_check_github_repo_accessible', monkey_patch_github_accessible)
 
     env.DEBUG = True
     description = 199 * '-'  # 200 characters is the limit.
     result = RUNNER.invoke(cli.train, [
-        '--grid_credential', CREDENTIAL_ID, '--grid_description', description,
-        '--grid_strategy', 'grid_search', '--grid_trials', "1",
-        '--ignore_warnings', 'tests/data/script.py'
+        '--grid_credential', CREDENTIAL_ID, '--grid_description', description, '--grid_strategy', 'grid_search',
+        '--grid_trials', "1", '--ignore_warnings', 'tests/data/script.py'
+    ])
+    assert result.exit_code == 0
+    assert not result.exception
+
+
+def test_train_with_nickname(monkeypatch):
+    """grid train returns 0 exit code"""
+    monkeypatch.setattr(grid, 'gql', lambda x: x)
+    monkeypatch.setattr(grid.Grid, '_init_client', monkey_patch_client)
+
+    monkeypatch.setattr(grid.Grid, 'get_credentials', monkey_patch_get_credentials)
+    monkeypatch.setattr(grid.Grid, '_set_local_credentials', lambda x: True)
+    monkeypatch.setattr(grid.Grid, '_check_user_github_token', monkey_patch_token_check)
+    monkeypatch.setattr(grid.Grid, '_check_github_repo_accessible', monkey_patch_github_accessible)
+
+    env.DEBUG = True
+    description = 199 * '-'  # 200 characters is the limit.
+    result = RUNNER.invoke(cli.train, [
+        '--grid_credential', CREDENTIAL_ID, '--grid_description', description, '--grid_instance_type', '2_cpu_4gb',
+        '--grid_strategy', 'grid_search', '--grid_trials', "1", '--ignore_warnings', 'tests/data/script.py'
     ])
     assert result.exit_code == 0
     assert not result.exception
@@ -427,20 +403,15 @@ def test_train_with_framework(monkeypatch):
     monkeypatch.setattr(grid, 'gql', lambda x: x)
     monkeypatch.setattr(grid.Grid, '_init_client', monkey_patch_client)
 
-    monkeypatch.setattr(grid.Grid, 'get_credentials',
-                        monkey_patch_get_credentials)
+    monkeypatch.setattr(grid.Grid, 'get_credentials', monkey_patch_get_credentials)
     monkeypatch.setattr(grid.Grid, '_set_local_credentials', lambda x: True)
-    monkeypatch.setattr(grid.Grid, '_check_user_github_token',
-                        monkey_patch_token_check)
-    monkeypatch.setattr(grid.Grid, '_check_github_repo_accessible',
-                        monkey_patch_github_accessible)
+    monkeypatch.setattr(grid.Grid, '_check_user_github_token', monkey_patch_token_check)
+    monkeypatch.setattr(grid.Grid, '_check_github_repo_accessible', monkey_patch_github_accessible)
 
     env.DEBUG = True
     result = RUNNER.invoke(cli.train, [
-        '--grid_credential', CREDENTIAL_ID, '--grid_description', 'test',
-        '--grid_strategy', 'grid_search', '--grid_trials', "1",
-        '--grid_framework', 'lightning', '--ignore_warnings',
-        'tests/data/script.py'
+        '--grid_credential', CREDENTIAL_ID, '--grid_description', 'test', '--grid_strategy', 'grid_search',
+        '--grid_trials', "1", '--grid_framework', 'lightning', '--ignore_warnings', 'tests/data/script.py'
     ])
     assert result.exit_code == 0
     assert not result.exception
