@@ -23,12 +23,12 @@ def test_check_if_uncommited_files(monkeypatch):
     # Make sure that we are not ignoring warnings.
     checks.env.IGNORE_WARNINGS = False
     result = checks.WorkflowChecksMixin._check_if_uncommited_files()
-    assert result == True
+    assert result is True
 
     _ignore = checks.env.IGNORE_WARNINGS
     checks.env.IGNORE_WARNINGS = True
     result = checks.WorkflowChecksMixin._check_if_uncommited_files()
-    assert result == False
+    assert result is False
 
     checks.env.IGNORE_WARNINGS = _ignore
 
@@ -41,18 +41,14 @@ def test_check_if_remote_head_is_different(mocker, monkeypatch):
     def monkey_patch_git_command_fatal(*args, **kwargs):
         return 'fatal'
 
-    monkeypatch.setattr(checks, 'execute_git_command',
-                        monkey_patch_git_command_fatal)
-    assert checks.WorkflowChecksMixin._check_if_remote_head_is_different(
-    ) is None
+    monkeypatch.setattr(checks, 'execute_git_command', monkey_patch_git_command_fatal)
+    assert checks.WorkflowChecksMixin._check_if_remote_head_is_different() is None
 
     def monkey_patch_git_command_same(*args, **kwargs):
         return 'foo'
 
-    monkeypatch.setattr(checks, 'execute_git_command',
-                        monkey_patch_git_command_same)
-    assert checks.WorkflowChecksMixin._check_if_remote_head_is_different(
-    ) == False
+    monkeypatch.setattr(checks, 'execute_git_command', monkey_patch_git_command_same)
+    assert checks.WorkflowChecksMixin._check_if_remote_head_is_different() is False
 
 
 def test_check_if_remote_head_is_different_shows_warning(mocker, monkeypatch):
