@@ -22,12 +22,10 @@ def get_click_confirm(holder):
 
 
 def test_check_dependency_spec_if_missing(monkeypatch):
-    monkeypatch.setattr(DependencyManager, "get_missing",
-                        lambda self: ["fake-package"])
+    monkeypatch.setattr(DependencyManager, "get_missing", lambda self: ["fake-package"])
     monkeypatch.setattr(dependencies, "PipManager", DependencyManager)
     output = []
-    monkeypatch.setattr(dependencies.click, "confirm",
-                        get_click_confirm(output))
+    monkeypatch.setattr(dependencies.click, "confirm", get_click_confirm(output))
     obj = dependencies.DependencyMixin()
     with pytest.raises(click.exceptions.Abort):
         obj._check_dependency_listing()
@@ -35,11 +33,9 @@ def test_check_dependency_spec_if_missing(monkeypatch):
 
 
 def test_check_dependency_spec_user_choice(monkeypatch):
-    monkeypatch.setattr(dependencies, 'execute_git_command',
-                        lambda *args, **kwargs: "")
+    monkeypatch.setattr(dependencies, 'execute_git_command', lambda *args, **kwargs: "")
     monkeypatch.setattr(os, "listdir", lambda p: ["requirements.txt"])
-    monkeypatch.setattr(dependencies, 'DISABLE_ON_DEPENDENCY_FILE_EXIST',
-                        False)
+    monkeypatch.setattr(dependencies, 'DISABLE_ON_DEPENDENCY_FILE_EXIST', False)
 
     monkeypatch.setattr(dependencies, "PipManager", DependencyManager)
 
@@ -63,10 +59,8 @@ def test_check_dependency_spec_user_choice(monkeypatch):
 
 
 def test_package_manager_selection(monkeypatch):
-    monkeypatch.setattr(dependencies, 'execute_git_command',
-                        lambda *args, **kwargs: "")
-    monkeypatch.setattr(dependencies, 'DISABLE_ON_DEPENDENCY_FILE_EXIST',
-                        False)
+    monkeypatch.setattr(dependencies, 'execute_git_command', lambda *args, **kwargs: "")
+    monkeypatch.setattr(dependencies, 'DISABLE_ON_DEPENDENCY_FILE_EXIST', False)
 
     def mock_init(self):
         self.get_missing = lambda: []
@@ -103,7 +97,6 @@ def test_package_manager_selection(monkeypatch):
 
 
 def test_if_both_pipfile_and_condafile(monkeypatch):
-    monkeypatch.setattr(os, "listdir",
-                        lambda p: ["environment.yml", "requirements.txt"])
+    monkeypatch.setattr(os, "listdir", lambda p: ["environment.yml", "requirements.txt"])
     obj = dependencies.DependencyMixin()
     assert obj._check_dependency_listing() is False
