@@ -14,23 +14,19 @@ def mp_execute(*args, **kwargs):
 
 def test_style_status():
     value = 'test'
-    result = base_observables.style_status(format_string=value,
-                                           status='running')
+    result = base_observables.style_status(format_string=value, status='running')
     assert '\x1b[33m' in result
     assert value in result
 
-    result = base_observables.style_status(format_string=value,
-                                           status='failed')
+    result = base_observables.style_status(format_string=value, status='failed')
     assert '\x1b[31m' in result
     assert value in result
 
-    result = base_observables.style_status(format_string=value,
-                                           status='finished')
+    result = base_observables.style_status(format_string=value, status='finished')
     assert '\x1b[32m' in result
     assert value in result
 
-    result = base_observables.style_status(format_string=value,
-                                           status='cancelled')
+    result = base_observables.style_status(format_string=value, status='cancelled')
     assert '\x1b[37m' in result
     assert value in result
 
@@ -47,8 +43,7 @@ class TestBaseObservable:
         cls.grid = grid.Grid(load_local_credentials=False)
         cls.grid._init_client()
 
-        cls.observable = base_observables.BaseObservable(
-            client=cls.grid.client)
+        cls.observable = base_observables.BaseObservable(client=cls.grid.client)
 
     def test_get_task_run_dependencies(self):
         results = self.observable._get_task_run_dependencies(run_name='test')
@@ -94,8 +89,7 @@ class TestBaseObservable:
                 'dependencies': [{
                     'taskId': 'test-task-0',
                     'status': 'failed',
-                    'taskType':
-                    'grid.core.repository_builder.RepositoryBuilder',
+                    'taskType': 'grid.core.repository_builder.RepositoryBuilder',
                     'message': 'Failed message',
                     'error': 'Failed error details'
                 }, {
@@ -107,13 +101,11 @@ class TestBaseObservable:
                 }, {
                     'taskId': 'test-task-2',
                     'status': 'running',
-                    'taskType':
-                    'grid.core.clusters.global_user_cluster.ReconcileCluster',
+                    'taskType': 'grid.core.clusters.global_user_cluster.ReconcileCluster',
                     'message': '',
                     'error': ''
                 }]
             }
 
-        monkeypatch.setattr(resolvers, 'get_run_task_status',
-                            mp_get_run_task_status)
+        monkeypatch.setattr(resolvers, 'get_run_task_status', mp_get_run_task_status)
         self.observable._get_task_run_status(run_name='test')
