@@ -26,8 +26,7 @@ class TestIneteractiveObservable:
     def test_get(self, capsys):
         interactive_node_observable.env.SHOW_PROCESS_STATUS_DETAILS = False
         interactive_node_observable.env.DEBUG = True
-        obsevable = interactive_node_observable.InteractiveNode(
-            client=self.grid.client)
+        obsevable = interactive_node_observable.InteractiveNode(client=self.grid.client)
 
         obsevable.get()
         captured = capsys.readouterr()
@@ -41,7 +40,6 @@ class TestIneteractiveObservable:
             raise TransportQueryError('test')
 
         monkeypatch.setattr(self.grid.client, 'execute', mp_transport_error)
-        obsevable = interactive_node_observable.InteractiveNode(
-            client=self.grid.client)
+        obsevable = interactive_node_observable.InteractiveNode(client=self.grid.client)
         with pytest.raises(click.ClickException):
             obsevable.get()
