@@ -22,10 +22,7 @@ class TestCredentialsUtilities:
             'lastUsedAt': 'test',
             'defaultCredential': 'test'
         }]
-        expected_columns = [
-            'Credential', 'Provider', 'Alias', 'Created At', 'Last Used At',
-            'Default'
-        ]
+        expected_columns = ['Credential', 'Provider', 'Alias', 'Created At', 'Last Used At', 'Default']
 
         with captured_output() as (out, _):
             print_creds_table(creds=credentials)
