@@ -313,24 +313,19 @@ class TestPackageContainer:
     def test_pip_package_from_distribution(self, monkeypatch):
         class DummyDistribution:
             project_name = "dummy-name"
-            as_requirement = lambda x: Requirement.parse("dummy-name==0.1.0"
-                                                         )  # noqa
+            as_requirement = lambda x: Requirement.parse("dummy-name==0.1.0")  # noqa
 
-        monkeypatch.setattr(dependency_manager, "_is_dist_editable",
-                            lambda x: True)
+        monkeypatch.setattr(dependency_manager, "_is_dist_editable", lambda x: True)
         with pytest.raises(RuntimeError, match="editable installation"):
             PipPackage.from_distribution(DummyDistribution())  # noqa
 
-        monkeypatch.setattr(dependency_manager, "_is_dist_editable",
-                            lambda x: False)
-        monkeypatch.setattr(dependency_manager, "_get_distribution_url",
-                            lambda x: None)
+        monkeypatch.setattr(dependency_manager, "_is_dist_editable", lambda x: False)
+        monkeypatch.setattr(dependency_manager, "_get_distribution_url", lambda x: None)
         pkg1 = PipPackage.from_distribution(DummyDistribution())  # noqa
         assert pkg1.name == "dummy-name"
         assert str(pkg1) == "dummy-name==0.1.0"
 
-        monkeypatch.setattr(dependency_manager, "_get_distribution_url",
-                            lambda x: "https://github.com/org/repo")
+        monkeypatch.setattr(dependency_manager, "_get_distribution_url", lambda x: "https://github.com/org/repo")
         pkg2 = PipPackage.from_distribution(DummyDistribution())  # noqa
         assert str(pkg2) == "dummy-name@ https://github.com/org/repo"
         # TODO: self._requirement_obj == other._requirement_obj is
@@ -451,16 +446,8 @@ class TestDepsManagerBaseClass:
         source_deps = ["pkg_a", "pkg_b", "pkg_c"]
 
         def test_setup(self):
-            self.env_deps = {
-                "pkg_z": object(),
-                "pkg_a": object(),
-                "pkg_b": object()
-            }
-            self.file_deps = {
-                "pkg_b": object(),
-                "pkg_c": object(),
-                "pkg_d": object()
-            }
+            self.env_deps = {"pkg_z": object(), "pkg_a": object(), "pkg_b": object()}
+            self.file_deps = {"pkg_b": object(), "pkg_c": object(), "pkg_d": object()}
             self._source_deps_list = source_deps
 
         # No missing keys
@@ -483,16 +470,8 @@ class TestDepsManagerBaseClass:
 
         def test_setup(self):
             self.req_file = dummyfile
-            self.env_deps = {
-                "pkg_z": object(),
-                "pkg_a": object(),
-                "pkg_b": object()
-            }
-            self.file_deps = {
-                "pkg_b": object(),
-                "pkg_c": object(),
-                "pkg_d": object()
-            }
+            self.env_deps = {"pkg_z": object(), "pkg_a": object(), "pkg_b": object()}
+            self.file_deps = {"pkg_b": object(), "pkg_c": object(), "pkg_d": object()}
             self._source_deps_list = source_deps
 
         # No requirement file exist
@@ -534,8 +513,7 @@ class TestDepsManagerBaseClass:
         source_deps = ["pkg_a", "pkg_b", "pkg_c", "pkg_d"]
         # monkeypatching safedump to ease testing
         yamlout = []
-        monkeypatch.setattr(yaml, "safe_dump", lambda c, f: yamlout.append(
-            (c, f)))
+        monkeypatch.setattr(yaml, "safe_dump", lambda c, f: yamlout.append((c, f)))
 
         def test_setup(self):
             self._source_deps_list = source_deps
@@ -546,21 +524,13 @@ class TestDepsManagerBaseClass:
         assert pm.write_config({"compute": {}}) is None
 
         # Empty config
-        monkeypatch.setattr(dependency_manager, "_get_system_deps",
-                            lambda x: [x])
+        monkeypatch.setattr(dependency_manager, "_get_system_deps", lambda x: [x])
         with pytest.raises(KeyError, match="compute"):
             pm.write_config({})
 
         # multiple system deps
         pm.write_config({"compute": {}})
-        assert yamlout[0][0] == {
-            'compute': {
-                'actions': {
-                    'on_image_build':
-                    ['apt install -y pkg_a pkg_b pkg_c pkg_d']
-                }
-            }
-        }
+        assert yamlout[0][0] == {'compute': {'actions': {'on_image_build': ['apt install -y pkg_a pkg_b pkg_c pkg_d']}}}
 
         configfile = yamlout[0][1]
         configfile.close()
@@ -568,14 +538,7 @@ class TestDepsManagerBaseClass:
 
         yamlout.clear()
         pm.write_config({"compute": {"actions": {"on_image_build": []}}})
-        assert yamlout[0][0] == {
-            'compute': {
-                'actions': {
-                    'on_image_build':
-                    ['apt install -y pkg_a pkg_b pkg_c pkg_d']
-                }
-            }
-        }
+        assert yamlout[0][0] == {'compute': {'actions': {'on_image_build': ['apt install -y pkg_a pkg_b pkg_c pkg_d']}}}
 
         configfile = yamlout[0][1]
         configfile.close()
@@ -594,10 +557,7 @@ class TestPipManager:
         pm.req_file = None
         dummyfile = DummyFile()
         monkeypatch.setattr(pm, "req_file", dummyfile)
-        final = {
-            "pkg_a": PipPackage.from_string("pkg-a==0.2"),
-            "pkg_b": PipPackage.from_string("pkg-b")
-        }
+        final = {"pkg_a": PipPackage.from_string("pkg-a==0.2"), "pkg_b": PipPackage.from_string("pkg-b")}
         assert pm._read_file_deps() == final
 
     def test_read_file_deps_with_invalid_file(self, monkeypatch):
