@@ -47,23 +47,16 @@ class TestGridInteractive:
             P.unlink(missing_ok=True)
 
     def mock_get_credentials(self):
-        return {
-            'getUserCredentials': [{
-                'credentialId': 'test',
-                'provider': 'test',
-                'defaultCredential': True
-            }]
-        }
+        return {'getUserCredentials': [{'credentialId': 'test', 'provider': 'test', 'defaultCredential': True}]}
 
     def test_grid_interactive_config(self):
         """Grid().train() executes a training operation correctly."""
-        grid = Grid(credential_path=self.creds_path,
-                    load_local_credentials=False)
+        grid = Grid(credential_path=self.creds_path, load_local_credentials=False)
         grid.get_credentials = self.mock_get_credentials
 
-        interactive_config = _generate_default_interactive_config(
-            credential_id='test', client=grid, instance_type='test')
+        interactive_config = _generate_default_interactive_config(credential_id='test',
+                                                                  client=grid,
+                                                                  instance_type='test')
 
         assert interactive_config['compute']['provider']['vendor'] == 'test'
-        assert interactive_config['compute']['provider'][
-            'credentials'] == 'test'
+        assert interactive_config['compute']['provider']['credentials'] == 'test'
