@@ -3,7 +3,6 @@ from datetime import timedelta
 from datetime import timezone
 import os
 from pathlib import Path
-import random
 import unittest
 
 import click
@@ -134,23 +133,21 @@ class UtilitiesTestCase(unittest.TestCase):
 
     def test_get_experiment_duration_string(self):
         created_at = str(datetime.now(timezone.utc) - timedelta(hours=3))
-        started_running_at = str(
-            datetime.now(timezone.utc) - timedelta(hours=2))
+        started_running_at = str(datetime.now(timezone.utc) - timedelta(hours=2))
         finished_at = str(datetime.now(timezone.utc) - timedelta(hours=1))
-        experiment_queued_result = get_experiment_duration_string(
-            created_at=created_at, started_running_at=None, finished_at=None)
+        experiment_queued_result = get_experiment_duration_string(created_at=created_at,
+                                                                  started_running_at=None,
+                                                                  finished_at=None)
         assert experiment_queued_result >= f"{0}d-{3:02d}:{0:02d}:{0:02d}"
         assert experiment_queued_result < f"{0}d-{3:02d}:{1:02d}:{0:02d}"
-        experiment_running_result = get_experiment_duration_string(
-            created_at=created_at,
-            started_running_at=started_running_at,
-            finished_at=None)
+        experiment_running_result = get_experiment_duration_string(created_at=created_at,
+                                                                   started_running_at=started_running_at,
+                                                                   finished_at=None)
         assert experiment_running_result >= f"{0}d-{2:02d}:{0:02d}:{0:02d}"
         assert experiment_running_result < f"{0}d-{2:02d}:{1:02d}:{0:02d}"
-        experiment_finished_result = get_experiment_duration_string(
-            created_at=created_at,
-            started_running_at=started_running_at,
-            finished_at=finished_at)
+        experiment_finished_result = get_experiment_duration_string(created_at=created_at,
+                                                                    started_running_at=started_running_at,
+                                                                    finished_at=finished_at)
         assert experiment_finished_result >= f"{0}d-{1:02d}:{0:02d}:{0:02d}"
         assert experiment_finished_result < f"{0}d-{1:02d}:{1:02d}:{0:02d}"
 
@@ -158,7 +155,5 @@ class UtilitiesTestCase(unittest.TestCase):
     def test_get_graphql_url():
         url_with_graphql = 'http://localhost:8000/graphql'
         url_without_graphql = 'http://localhost:8000'
-        assert get_graphql_url(
-            url_without_graphql) == 'http://localhost:8000/graphql'
-        assert get_graphql_url(
-            url_with_graphql) == 'http://localhost:8000/graphql'
+        assert get_graphql_url(url_without_graphql) == 'http://localhost:8000/graphql'
+        assert get_graphql_url(url_with_graphql) == 'http://localhost:8000/graphql'
